/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_CHAFFVERB_HPP_
#define _HEAVY_CONTEXT_CHAFFVERB_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalDel1.h"
#include "HvMath.h"
#include "HvControlPack.h"
#include "HvControlSystem.h"
#include "HvSignalLine.h"
#include "HvSignalTabread.h"
#include "HvSignalRPole.h"
#include "HvSignalPhasor.h"
#include "HvControlCast.h"
#include "HvControlTabhead.h"
#include "HvControlSlice.h"
#include "HvControlDelay.h"
#include "HvTable.h"
#include "HvSignalVar.h"
#include "HvControlVar.h"
#include "HvControlUnop.h"
#include "HvControlRandom.h"
#include "HvControlIf.h"
#include "HvSignalTabwrite.h"
#include "HvControlBinop.h"

class Heavy_ChaffVerb : public HeavyContext {

 public:
  Heavy_ChaffVerb(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_ChaffVerb();

  const char *getName() override { return "ChaffVerb"; }
  int getNumInputChannels() override { return 1; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        A__LFO_PERIOD = 0x1F30993F, // A__LFO_Period
        A__LFO_STEPS_SCALE__TYPE2 = 0x1A2B8E9F, // A__LFO_Steps_Scale__Type2
        A__LFO_STEPS__TYPE2 = 0xBE3344C8, // A__LFO_Steps__Type2
        A__LFO_SWITCH = 0x7369936E, // A__LFO_Switch
        A__LFO_TYPE = 0xD64CFD23, // A__LFO_type
        B__GENERAL_OFFSET = 0x51447E19, // B__General_Offset
        B__GENERAL_SCALE = 0xA10FCFC4, // B__General_Scale
        C__RANDOM_LFO_OFFSET = 0x7EFB8E46, // C__Random_LFO_Offset
        C__RANDOM_LFO_PERIOD = 0xE6223016, // C__Random_LFO_Period
        C__RANDOM_LFO_SCALE = 0x3281900D, // C__Random_LFO_Scale
        C__RANDOM_LFO_SWITCH = 0x6150BC53, // C__Random_LFO_Switch
        D__SHIFT_MICROTONE = 0x9CBB1BF3, // D__Shift_Microtone
        D__SHIFT_TRANSPOSE = 0x4439D71, // D__Shift_Transpose
        E__FX_LEVEL = 0x890283C2, // E__Fx_Level
        E__HIPASS_FREQ = 0x12962685, // E__HiPass_Freq
        E__SHIFT_DELAY = 0x183CFEE5, // E__Shift_Delay
        E__SHIFT_WINDOW = 0x57FF40DB, // E__Shift_Window
        F__FX_DELAY = 0x69A91334, // F__FX_Delay
        F__FX_DELAY_FEEDBACK = 0x68D029F7, // F__FX_Delay_Feedback
        MIX__DRY_MIX = 0xD63693D0, // Mix__Dry_Mix
        MIX__DRY_VOL = 0x1FC3C02C, // Mix__Dry_Vol
        MIX__REVERB_LEVEL = 0x58653D84, // Mix__Reverb_Level
        MIX__REVERB_VOL = 0xE764F673, // Mix__Reverb_Vol
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_j5nvqSJP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Y7Mv0xII_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_GczL4rTy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Zp57mptB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DLtlM46D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YyHMK2aW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_cuEElywh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_w7x1ePiN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gTd7Fn8N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_82nEWbyQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Bu0OUJX5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hYzdihKr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_gzgvYEKy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_W2UaS4hN_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_T82ydbjn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_dkBXVOFZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eKi7vHri_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w17LqwBp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kxKz7D6N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_q2i10ki5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CJu9g727_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YxPC6dK8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qgCXF2IX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8UGELcJV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oVunIFaQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_A8zVkXWq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ftm2kpri_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NUKILwVC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3bdFOm63_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N60Ixq33_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_oSZsxJvM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OJ359UeV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_XhgASOXS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0e0JzboO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W8bEwQto_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZTTMx9Yx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZmIRzsJZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8yrdlRvT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HUTuZCpw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SmCvvjxG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MXNaulKQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jKszPbhK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AgAtVmSa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HQ45Yv1z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_24f1fy54_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_a6zmeojr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LjEx9g3G_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_pTS9qXd1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Yem3Ly6T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_w8lVIh0c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vZwPIPUL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3JV5IYMv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vMxs1m4F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lp2NgwuV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_KqoFg9o5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X8kBlean_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uwEFkceL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RnyTzVpv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0S0N00Ig_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZvnlX7QI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UluI8Bf0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gX4SYFPR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I024vmFu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_RN8hSmWc_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_VHoy4jx8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_GAyJNwSQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cRandom_I445K91c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_GaOwLe9n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1AynuYoS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_P2cgDwI8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QelQapNG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DcRVp6kE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hTxV92Ut_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_L2Ua2viC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CIfctNYt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7yNC17Ad_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VQSg6Y38_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qSQcgx7O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_JY6feawi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6I4sTYfX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dzskrm20_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4AUPQKZB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_0hoMElzM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_XwAFkPNN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_bsqk3m8h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XAJhLEJg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SwVlYJTP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S8ECBZiy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7KAI1o9m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3eVVsNF7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_En7wzmvI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CPPqI6mb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7r4BhU4Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ysc9To9E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0FPOfYSm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g9NVpvVB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IyGbaZ4m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_Zbb23RTW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iDubDUz7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jaSaMo3r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2WMtqrKQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_8KN0Dg3F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_OPZa4J3Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_Pf8Caw31_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gP5U4Taj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sZOV2VTh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JjD28HOg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_EVL70ujK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hoFhcE6b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_76O8oXzv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s51VwQUP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tQ1QdvHE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9DhbiYr7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aYwsKlhO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2EnGoiPd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_U12EJciL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_altUcpBY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mCawOMRv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fVr3SrlU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Dc0sXUgZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_kJZCX7Yo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Imv1iIVJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_gULkidyi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0HtiOmUo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lq0z28OQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QyMWb2pM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_CQeQNXJO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9KYrrfGz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O9rd20k3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rvlX9iTS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mVWCnmZY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fC3HXrwn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Cg6MhJWd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TN62v8JE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ki4WfTm1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_iZYtEKa5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_efUGlpnc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_pyuypEiC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZDhXYvXv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_wt6vF1mo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_TJFl8EU3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_7tIINPOS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_skp5p1Wy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xFjN9nVy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kTOcaHy5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7QCdPwDl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q1L3Zc0k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MnCPDe7N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TiR7qfTT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XDDh0rhv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a5R0IEZO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gCJXplcu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PuPYBHKs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_m1Fwvt22_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I5ki9PAK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_DrDMk2Ec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_tw44yydW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_dvHHama0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_SnBzZhZB_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_SMTViuja_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_WCN6whYK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_f4Y4e5b2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P49zYBbb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TkuFnmOy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2zY8tmyg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NFhF36Pj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wvRD3n7H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bWPVsmmP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_R04u5wWx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_QfsauD2v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_MsUieQib_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_v6lDltmB_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_34Xk0nNl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_LePuUY6p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HAOMk4Xu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_thWVPBIE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XgCc8avo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_H4RAtANo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rgRzWQOA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OgYZzvsM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3rtlKPzO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ssMBg8tv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_1QbVqyH7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_bdmU8f40_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_HwvlsSsF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_o1Uu6Akz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_BchNK2H7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i7UYoUCF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jHolRwr1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CVr09vOA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4WThvooa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QI4Kak8c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AONCR0A8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QmJa2Shl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_9XjGhMwz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_iqGGZ5zd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_gVW4yvUQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mwPv5qnn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_Jgreo8nv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_bE9ne5ST_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TMpTiQ9U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rCoPap82_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rmH0W9KV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Kkq1RBmE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b4ghMUyN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_omRuSjb1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_qYRkAo8i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_D5RCZpEr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oUbUxb6d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KtWOfnUU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wtIbebV2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zybmaf4i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_I9QPPgYH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4sq0A6aY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OV1yP2zv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e0CbgBS9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hU0VZVni_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zwzaN8rh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jjJG6llo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8ADDGzmp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ha5AksLM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8Hw8EnAU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4J8Wd9NU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rjrAe9if_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OSIodmVs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i8i7FGbR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DViR7tDZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iNBB7xBp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1R8nV73E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Fp0k3ekJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_bUEzfCmo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_9GuVojHv_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_xKIBhOeI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_uzJfL0n7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GQDYwYYo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_coXsF9b4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_76Al9vAu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lO1Dfpdm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jUnSelrn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FFvrHTT8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_HXqiHGef_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WeG10SZN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Y06H89fu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rIKEKlny_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_zcXeCgyB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_F8SswYZu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_oZbqnJdr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QOvIwfuL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IZe9dsgb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oHUAcmjX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xiDTRnK7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OrwjBpPo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hANhUuAh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5jFx4EkI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b2pNDpf3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jnAPQmvC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0sLpJRym_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JOXiNK1o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Svq6ntMG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JYqGiHaX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_erAhIe7R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_6Sg61IJF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_BfN2fuiy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Vpl9O388_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_34Dl9E0u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_rShBuISs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Qzasq3Ju_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HUnmW31y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k5NUVBwB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jodJLHBx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dkkV6PEe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SilGNlpU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_BbrRDu9M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Oq62Enkl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_EhHOlZhe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4nRoI4PF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hxIJGdSQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_pzV5sGDq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_KZ0v6kZ2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MMehdqSr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_geECz5Gu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gZEBhVHb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0srMnz6I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I71AokXo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hZMfL9bZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xld6Pxy3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ipa22ppI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0O1qlohm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qWGHmhTh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VFrKWMpF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PkaARKgy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hAdeH2CU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_k2vAzLiv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_E5qzbfDJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_OtuM2jdA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0ZcOcn40_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_BpSwpKBh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_sqYl8sin_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8NRQLwtL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9xKcOWZB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YfxK1Pb0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JgVAna10_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HV81fptC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dMBMGj12_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_G3m1a7cE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Pa1TmUYL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_A9ojJNXO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jd78CtIK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_eysDd6SZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_emRYwdNA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_xWpkrcHI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y6Rq2u1V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hg0MsJh4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tTcFCjLp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_tkYzaq2u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_J95MXmX0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5YBGaWW2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5LDXlkmH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aynaolHI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QXryoE1R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X8q1ANxL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5aDP6YJu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WcRyi5yl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NOUfYYBC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8KMcppte_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_oZ0eWzZv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_vJWzHppQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_vPLIJ9NN_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_nr9hcmG9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_PpWhMVhn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AZ1yOCyG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HwGisarQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LR6HCCau_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_taiuHeQf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gkdoywtK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZdD368PM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_223ZrU65_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iEZSmqrJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_kkfYAExb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2HlKg5s2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_nEXUWebE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_LIiALJuS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_o9xlsr3h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TjDKnMA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_awcg9lCf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5IrKbHW1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_OqlyPdpp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n1JJPvYo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uzUZwZ7i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DdlEoPcu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ji3da3ZD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QdKhH2uS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Eyt53xdJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L3qyQmz1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CXVbAjd1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lLqmEPaB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_MFqJMr1N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_gwogWSC8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_DFId1suu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_XomOoucD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_TDlTrzVn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_8TEf7XSC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ka3Xw83a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_28PNvjLN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xp5J7Q4i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qYMjNW9S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Jrd8bXqL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KNeN6Edt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_FVQBiQSs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JXlmO157_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_wRyK2FoD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ta0qCkjA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_AUe6XDIy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_6gfGygnV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_TTyDYDuZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1NhagQTO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EkFuP2Qx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VNmdPpjk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_wpyCfU8l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2XLnqe3h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gqLUDqvv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ulZXo95N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sIMzRrzx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gB0oAR7c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sUQb65RI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qlYX83Ic_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a5IEqaep_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gdNjJg7H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Y77G1TYy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_1yWFXi0s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_UwI3G47h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_AXelklwA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_BwcV4BR8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_CyQz2ryL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JeAGeY5V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8SdQUNnl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Upq6wetg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bPcbdU6L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EefvhgRi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PIxPScKj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_UIW1LznG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9s5nvQAv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_zOCHQAYt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_p3nn0JdC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_shb9SE1I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_fkt9imvW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_MqWH9iOI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ce7s3GQr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9WEHQ4Y2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m4jp1url_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_USEv7WyM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_584Evofi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_byLaokHY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WkZzTjVo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kkxJC04R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_L1rfjftq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ryEwlVYy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rYILDlbK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RIhgAcYD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1UWACGH9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Z3Aktc3C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_aD3N9Uhi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lBZRWxTv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QFYs2eat_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_G6l7tDvX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YBXa1Rti_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z8OOPXp0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3Ma8mona_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_541vmR42_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UzZdxetZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zh9XuY3S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7EE0Wex0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RNbhx1WN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hZUiNhVc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MNQvS8v1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E4eubT5k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wTwfyTdK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RPmSMtO1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DwbME5fc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qyz183bH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UtcA5vY3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_utWXQMPH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_BMspjrpR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fGQ89Pfb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wOTss16k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rV6I1nPJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lc2WFj1T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BGzQ8OLb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ps0sTM2q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oP6RWEWU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D0umbA5h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gbx76kVC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5GUuDzAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oNLthuZJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_tGiDF9kU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AibGQCnw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jQmFHAqh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_DjQu1cCX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1EA5XEP5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xkGj34Hf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WM8EAZ8d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MgxUUoLr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BlXcb0Yv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KI2Xa37x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_59Ervc34_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_lT6xyCgI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_JdKdfhAY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_uh0nZfhs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GNjmzSpI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fLzBzLs9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Xr4zCWUD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_QFiH8UA1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_oWWlS9GR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_lxDdZyGE_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_TZCUZqND_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_Pb8JBdIn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RaM6y1Rj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VlxioCHd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X9bCoI2o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IOriLOSR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L9K2j7m3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h1EktLEH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_stZ6Ksrm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0E4nZMrA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_n2vxtfNh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PlRh3U8t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_mQ8D3avh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_PzdMH4p2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_JpZ3w5Mb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xFs4Xsgy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fvySqpdU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EmwJ9Ilb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0kcuqAlm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FNtTbUgu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WqEAdn7Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jLcxfUQy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gdEeuN05_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nQ1SWBno_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QtUinRzs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s6xFKEkw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EY5pgjnl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4wb1bcMm_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_2KkD4eBx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LipFYMTZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Ax088eZb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_iZUPSvmA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rBeE5Hr9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sfzs14Gn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xqn2TdMI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_886kD50T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_m2aktvwy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_sYHC5dKg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_xkJQUEqA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_23yQI59R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nTv34s5b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gBK2ClT2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Prn6JYsR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_FqPpvLNo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_iQ4OMYl6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p9s47JFu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_H8bTnhF6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_mSMNvRM4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_qubknck7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sVcCB2rT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zkzDUhBy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6PsfRC9h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ShIBZiWJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yMskSg4v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ljxK8xRK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ta4NokNb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_nMFx0i3X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Ea6VEyy4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_VOjCbw16_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4CqKjsBB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_PlbJmkj4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W0PFAF5l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K1c2mgbW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r7vU22kH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4SArSTUE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jHaVPOqC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rn43klyD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bggxhu6R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UIdQyEPU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ilRbDb7h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xRrZUycG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M6z7g5xz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kmvuOvQY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2jGub9t4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ozF0lQlr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DUV1cUEN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kvLrvGYS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EAw8QYCE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_myWN2OBD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y4UMDK2U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VxxJ5ROH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bM2BSzjY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2eCMCrgq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NV8X4x17_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R4t0oTAP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ccqZboCg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vdxNNsXe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cJ0QiSri_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u1CLaGaa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_szFvVZHb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LsWNJBJc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nwhuSFFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_w87d2Tvj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a0odJvlJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c5F46YwY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7Uen9V7u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t2ZwZVK1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vGK1GzaQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PxeuxMNe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pY9SEvGH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HO2QCa8a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1Kd9C7dh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7L27QsNf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kALoFRl3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8fY3naMX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_m8tbQ9uh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QH94rVfN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9BwMXKXm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sMowLSnf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_P9PebINy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NBXnPyJ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MkQEhkja_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2kh2VRtT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wo4yv7XS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HH0uy2ie_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_aOOkkEgo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4XuwuZuI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_T3ihUu5s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vWgsNPsL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VFDVpqBf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QCHDi9vB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3jn2O1Nw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gJzdxH30_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sW0RXAIV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_s8dKQ0fH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tN7youEZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_REytMAWh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5NJF82WT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_O9gKiWdP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rBtlhfJk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0Ywf6VDu_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalPhasor sPhasor_5lSPLxw2;
  SignalLine sLine_j38q5Sh6;
  SignalLine sLine_F0Jkbzms;
  SignalTabhead sTabhead_l9WsAcen;
  SignalTabread sTabread_V1RoKIgy;
  SignalTabread sTabread_TrRonSpA;
  SignalTabhead sTabhead_QTyUkdH9;
  SignalTabread sTabread_yVuhhqpz;
  SignalTabread sTabread_TaxFNQfy;
  SignalTabwrite sTabwrite_pZJF94pi;
  SignalRPole sRPole_MDM2KImo;
  SignalDel1 sDel1_UtWig8i2;
  SignalTabread sTabread_JpZ3w5Mb;
  SignalTabwrite sTabwrite_HWfMrUFA;
  SignalTabread sTabread_bsqk3m8h;
  SignalRPole sRPole_hwcpYarA;
  SignalLine sLine_eJ5jMpbR;
  SignalLine sLine_ZHE9GDwp;
  SignalTabread sTabread_oZbqnJdr;
  SignalTabread sTabread_KZ0v6kZ2;
  SignalTabread sTabread_xWpkrcHI;
  SignalTabread sTabread_o9xlsr3h;
  SignalTabread sTabread_MqWH9iOI;
  SignalTabread sTabread_TTyDYDuZ;
  SignalTabwrite sTabwrite_9HVhWerm;
  SignalTabwrite sTabwrite_9NMMb84r;
  SignalTabwrite sTabwrite_5iV3dFqL;
  SignalTabwrite sTabwrite_LeOf7Yvh;
  SignalTabwrite sTabwrite_Hc6xyqzq;
  SignalTabwrite sTabwrite_AwOG3Qk1;
  SignalTabread sTabread_Pf8Caw31;
  SignalRPole sRPole_EvinB8mB;
  SignalTabread sTabread_gULkidyi;
  SignalRPole sRPole_xKnmE4bU;
  SignalTabread sTabread_7tIINPOS;
  SignalRPole sRPole_7hdmz0eI;
  SignalTabwrite sTabwrite_PgPn9nrj;
  SignalTabwrite sTabwrite_9GqrFB3i;
  SignalTabwrite sTabwrite_uPKXWkof;
  SignalTabwrite sTabwrite_JbR6MEOD;
  SignalLine sLine_pr3NjtZ3;
  ControlVar cVar_j5nvqSJP;
  ControlVar cVar_Y7Mv0xII;
  ControlPack cPack_GczL4rTy;
  ControlBinop cBinop_DLtlM46D;
  ControlVar cVar_YyHMK2aW;
  ControlPack cPack_cuEElywh;
  ControlVar cVar_w7x1ePiN;
  ControlVar cVar_gTd7Fn8N;
  ControlDelay cDelay_hYzdihKr;
  ControlDelay cDelay_gzgvYEKy;
  ControlBinop cBinop_T82ydbjn;
  HvTable hTable_dkBXVOFZ;
  ControlBinop cBinop_w17LqwBp;
  ControlVar cVar_oVunIFaQ;
  ControlBinop cBinop_Ftm2kpri;
  ControlBinop cBinop_3bdFOm63;
  SignalVarf sVarf_HiQO2z3M;
  SignalVarf sVarf_mkxZFISX;
  SignalVarf sVarf_NuTrgtoe;
  ControlVar cVar_OJ359UeV;
  ControlBinop cBinop_0e0JzboO;
  ControlBinop cBinop_ZTTMx9Yx;
  SignalVarf sVarf_8Fd4WEAn;
  SignalVarf sVarf_IpPouE2U;
  SignalVarf sVarf_wxyC3mEu;
  ControlBinop cBinop_ZmIRzsJZ;
  ControlBinop cBinop_8yrdlRvT;
  ControlBinop cBinop_MXNaulKQ;
  ControlBinop cBinop_jKszPbhK;
  ControlBinop cBinop_AgAtVmSa;
  ControlBinop cBinop_HQ45Yv1z;
  ControlBinop cBinop_24f1fy54;
  ControlBinop cBinop_vZwPIPUL;
  ControlBinop cBinop_3JV5IYMv;
  SignalVarf sVarf_XzQQSXwW;
  ControlVar cVar_vMxs1m4F;
  ControlBinop cBinop_X8kBlean;
  ControlBinop cBinop_uwEFkceL;
  ControlBinop cBinop_0S0N00Ig;
  ControlBinop cBinop_ZvnlX7QI;
  ControlBinop cBinop_UluI8Bf0;
  ControlBinop cBinop_gX4SYFPR;
  ControlBinop cBinop_I024vmFu;
  SignalVarf sVarf_zOG8ATgT;
  ControlBinop cBinop_VHoy4jx8;
  ControlRandom cRandom_I445K91c;
  ControlSlice cSlice_GaOwLe9n;
  ControlDelay cDelay_P2cgDwI8;
  ControlVar cVar_L2Ua2viC;
  ControlBinop cBinop_7yNC17Ad;
  ControlBinop cBinop_VQSg6Y38;
  ControlBinop cBinop_qSQcgx7O;
  ControlTabhead cTabhead_JY6feawi;
  ControlVar cVar_4AUPQKZB;
  ControlDelay cDelay_0hoMElzM;
  ControlDelay cDelay_XwAFkPNN;
  ControlBinop cBinop_XAJhLEJg;
  ControlBinop cBinop_SwVlYJTP;
  ControlBinop cBinop_S8ECBZiy;
  ControlBinop cBinop_7r4BhU4Q;
  ControlBinop cBinop_0FPOfYSm;
  ControlBinop cBinop_g9NVpvVB;
  ControlTabhead cTabhead_Zbb23RTW;
  ControlVar cVar_2WMtqrKQ;
  ControlDelay cDelay_8KN0Dg3F;
  ControlDelay cDelay_OPZa4J3Q;
  ControlBinop cBinop_gP5U4Taj;
  ControlBinop cBinop_sZOV2VTh;
  ControlBinop cBinop_JjD28HOg;
  ControlBinop cBinop_tQ1QdvHE;
  ControlBinop cBinop_aYwsKlhO;
  ControlBinop cBinop_2EnGoiPd;
  ControlTabhead cTabhead_altUcpBY;
  ControlVar cVar_Dc0sXUgZ;
  ControlDelay cDelay_kJZCX7Yo;
  ControlDelay cDelay_Imv1iIVJ;
  ControlBinop cBinop_0HtiOmUo;
  ControlBinop cBinop_lq0z28OQ;
  ControlBinop cBinop_QyMWb2pM;
  ControlBinop cBinop_mVWCnmZY;
  ControlBinop cBinop_Cg6MhJWd;
  ControlBinop cBinop_TN62v8JE;
  ControlTabhead cTabhead_iZYtEKa5;
  ControlVar cVar_ZDhXYvXv;
  ControlDelay cDelay_wt6vF1mo;
  ControlDelay cDelay_TJFl8EU3;
  ControlBinop cBinop_skp5p1Wy;
  ControlBinop cBinop_xFjN9nVy;
  ControlBinop cBinop_kTOcaHy5;
  ControlBinop cBinop_XDDh0rhv;
  ControlBinop cBinop_gCJXplcu;
  ControlBinop cBinop_PuPYBHKs;
  ControlDelay cDelay_tw44yydW;
  ControlDelay cDelay_dvHHama0;
  ControlBinop cBinop_SMTViuja;
  HvTable hTable_WCN6whYK;
  ControlBinop cBinop_P49zYBbb;
  ControlDelay cDelay_QfsauD2v;
  ControlDelay cDelay_MsUieQib;
  ControlBinop cBinop_34Xk0nNl;
  HvTable hTable_LePuUY6p;
  ControlBinop cBinop_thWVPBIE;
  ControlDelay cDelay_1QbVqyH7;
  ControlDelay cDelay_bdmU8f40;
  ControlBinop cBinop_o1Uu6Akz;
  HvTable hTable_BchNK2H7;
  ControlBinop cBinop_jHolRwr1;
  ControlDelay cDelay_iqGGZ5zd;
  ControlDelay cDelay_gVW4yvUQ;
  ControlBinop cBinop_Jgreo8nv;
  HvTable hTable_bE9ne5ST;
  ControlBinop cBinop_rCoPap82;
  ControlPack cPack_qYRkAo8i;
  ControlPack cPack_D5RCZpEr;
  ControlBinop cBinop_oUbUxb6d;
  ControlBinop cBinop_KtWOfnUU;
  ControlVar cVar_wtIbebV2;
  ControlBinop cBinop_4sq0A6aY;
  ControlBinop cBinop_OV1yP2zv;
  SignalVarf sVarf_vzHyYz4V;
  ControlBinop cBinop_hU0VZVni;
  ControlBinop cBinop_zwzaN8rh;
  ControlBinop cBinop_jjJG6llo;
  SignalVarf sVarf_pkqbUEM8;
  ControlVar cVar_8ADDGzmp;
  ControlVar cVar_ha5AksLM;
  ControlVar cVar_8Hw8EnAU;
  ControlVar cVar_4J8Wd9NU;
  ControlIf cIf_rjrAe9if;
  ControlBinop cBinop_OSIodmVs;
  ControlBinop cBinop_i8i7FGbR;
  ControlBinop cBinop_DViR7tDZ;
  ControlDelay cDelay_Fp0k3ekJ;
  ControlDelay cDelay_bUEzfCmo;
  ControlBinop cBinop_xKIBhOeI;
  HvTable hTable_uzJfL0n7;
  ControlBinop cBinop_coXsF9b4;
  ControlTabhead cTabhead_HXqiHGef;
  ControlVar cVar_rIKEKlny;
  ControlDelay cDelay_zcXeCgyB;
  ControlDelay cDelay_F8SswYZu;
  ControlBinop cBinop_QOvIwfuL;
  ControlBinop cBinop_IZe9dsgb;
  ControlBinop cBinop_oHUAcmjX;
  ControlBinop cBinop_b2pNDpf3;
  ControlBinop cBinop_0sLpJRym;
  ControlBinop cBinop_JOXiNK1o;
  ControlDelay cDelay_6Sg61IJF;
  ControlDelay cDelay_BfN2fuiy;
  ControlBinop cBinop_34Dl9E0u;
  HvTable hTable_rShBuISs;
  ControlBinop cBinop_HUnmW31y;
  ControlTabhead cTabhead_BbrRDu9M;
  ControlVar cVar_4nRoI4PF;
  ControlDelay cDelay_hxIJGdSQ;
  ControlDelay cDelay_pzV5sGDq;
  ControlBinop cBinop_MMehdqSr;
  ControlBinop cBinop_geECz5Gu;
  ControlBinop cBinop_gZEBhVHb;
  ControlBinop cBinop_ipa22ppI;
  ControlBinop cBinop_qWGHmhTh;
  ControlBinop cBinop_VFrKWMpF;
  ControlDelay cDelay_E5qzbfDJ;
  ControlDelay cDelay_OtuM2jdA;
  ControlBinop cBinop_BpSwpKBh;
  HvTable hTable_sqYl8sin;
  ControlBinop cBinop_9xKcOWZB;
  ControlTabhead cTabhead_G3m1a7cE;
  ControlVar cVar_jd78CtIK;
  ControlDelay cDelay_eysDd6SZ;
  ControlDelay cDelay_emRYwdNA;
  ControlBinop cBinop_Y6Rq2u1V;
  ControlBinop cBinop_hg0MsJh4;
  ControlBinop cBinop_tTcFCjLp;
  ControlBinop cBinop_aynaolHI;
  ControlBinop cBinop_X8q1ANxL;
  ControlBinop cBinop_5aDP6YJu;
  ControlDelay cDelay_oZ0eWzZv;
  ControlDelay cDelay_vJWzHppQ;
  ControlBinop cBinop_nr9hcmG9;
  HvTable hTable_PpWhMVhn;
  ControlBinop cBinop_HwGisarQ;
  ControlTabhead cTabhead_223ZrU65;
  ControlVar cVar_2HlKg5s2;
  ControlDelay cDelay_nEXUWebE;
  ControlDelay cDelay_LIiALJuS;
  ControlBinop cBinop_TjDKnMA9;
  ControlBinop cBinop_awcg9lCf;
  ControlBinop cBinop_5IrKbHW1;
  ControlBinop cBinop_Ji3da3ZD;
  ControlBinop cBinop_Eyt53xdJ;
  ControlBinop cBinop_L3qyQmz1;
  ControlDelay cDelay_gwogWSC8;
  ControlDelay cDelay_DFId1suu;
  ControlBinop cBinop_TDlTrzVn;
  HvTable hTable_8TEf7XSC;
  ControlBinop cBinop_28PNvjLN;
  ControlTabhead cTabhead_FVQBiQSs;
  ControlVar cVar_ta0qCkjA;
  ControlDelay cDelay_AUe6XDIy;
  ControlDelay cDelay_6gfGygnV;
  ControlBinop cBinop_1NhagQTO;
  ControlBinop cBinop_EkFuP2Qx;
  ControlBinop cBinop_VNmdPpjk;
  ControlBinop cBinop_sIMzRrzx;
  ControlBinop cBinop_sUQb65RI;
  ControlBinop cBinop_qlYX83Ic;
  ControlDelay cDelay_1yWFXi0s;
  ControlDelay cDelay_UwI3G47h;
  ControlBinop cBinop_BwcV4BR8;
  HvTable hTable_CyQz2ryL;
  ControlBinop cBinop_8SdQUNnl;
  ControlTabhead cTabhead_UIW1LznG;
  ControlVar cVar_p3nn0JdC;
  ControlDelay cDelay_shb9SE1I;
  ControlDelay cDelay_fkt9imvW;
  ControlBinop cBinop_ce7s3GQr;
  ControlBinop cBinop_9WEHQ4Y2;
  ControlBinop cBinop_m4jp1url;
  ControlBinop cBinop_kkxJC04R;
  ControlBinop cBinop_ryEwlVYy;
  ControlBinop cBinop_rYILDlbK;
  ControlVar cVar_1UWACGH9;
  ControlVar cVar_Z3Aktc3C;
  ControlPack cPack_aD3N9Uhi;
  ControlVar cVar_lBZRWxTv;
  ControlBinop cBinop_YBXa1Rti;
  ControlBinop cBinop_z8OOPXp0;
  SignalVarf sVarf_ZtaDrvMv;
  ControlBinop cBinop_541vmR42;
  ControlBinop cBinop_UzZdxetZ;
  ControlBinop cBinop_Zh9XuY3S;
  SignalVarf sVarf_Znay01cp;
  ControlVar cVar_7EE0Wex0;
  ControlBinop cBinop_MNQvS8v1;
  ControlBinop cBinop_E4eubT5k;
  SignalVarf sVarf_iUcGroED;
  ControlBinop cBinop_RPmSMtO1;
  ControlBinop cBinop_DwbME5fc;
  ControlBinop cBinop_Qyz183bH;
  SignalVarf sVarf_vccBUjBq;
  ControlVar cVar_UtcA5vY3;
  ControlBinop cBinop_fGQ89Pfb;
  ControlBinop cBinop_wOTss16k;
  SignalVarf sVarf_6Tm0cU7G;
  ControlBinop cBinop_lc2WFj1T;
  ControlBinop cBinop_BGzQ8OLb;
  ControlBinop cBinop_Ps0sTM2q;
  SignalVarf sVarf_QSdT0VTN;
  ControlBinop cBinop_oP6RWEWU;
  ControlBinop cBinop_gbx76kVC;
  ControlBinop cBinop_5GUuDzAS;
  ControlDelay cDelay_tGiDF9kU;
  ControlVar cVar_1EA5XEP5;
  ControlBinop cBinop_WM8EAZ8d;
  ControlBinop cBinop_MgxUUoLr;
  ControlBinop cBinop_BlXcb0Yv;
  ControlVar cVar_KI2Xa37x;
  ControlVar cVar_59Ervc34;
  ControlIf cIf_uh0nZfhs;
  ControlBinop cBinop_GNjmzSpI;
  ControlDelay cDelay_QFiH8UA1;
  ControlDelay cDelay_oWWlS9GR;
  ControlBinop cBinop_TZCUZqND;
  HvTable hTable_Pb8JBdIn;
  ControlBinop cBinop_VlxioCHd;
  ControlTabhead cTabhead_stZ6Ksrm;
  ControlVar cVar_PlRh3U8t;
  ControlDelay cDelay_mQ8D3avh;
  ControlDelay cDelay_PzdMH4p2;
  ControlBinop cBinop_xFs4Xsgy;
  ControlBinop cBinop_fvySqpdU;
  ControlBinop cBinop_EmwJ9Ilb;
  ControlBinop cBinop_gdEeuN05;
  ControlBinop cBinop_QtUinRzs;
  ControlBinop cBinop_s6xFKEkw;
  ControlVar cVar_LipFYMTZ;
  ControlVar cVar_rBeE5Hr9;
  ControlVar cVar_sfzs14Gn;
  ControlVar cVar_xqn2TdMI;
  ControlVar cVar_886kD50T;
  ControlVar cVar_m2aktvwy;
  ControlIf cIf_23yQI59R;
  ControlBinop cBinop_nTv34s5b;
  ControlVar cVar_gBK2ClT2;
  ControlIf cIf_iQ4OMYl6;
  ControlBinop cBinop_p9s47JFu;
  ControlSlice cSlice_mSMNvRM4;
  ControlSlice cSlice_qubknck7;
  ControlVar cVar_sVcCB2rT;
  ControlIf cIf_zkzDUhBy;
  ControlBinop cBinop_yMskSg4v;
  ControlIf cIf_nMFx0i3X;
  ControlIf cIf_Ea6VEyy4;
  ControlIf cIf_VOjCbw16;
  ControlIf cIf_4CqKjsBB;
  ControlIf cIf_PlbJmkj4;
  SignalVarf sVarf_SEsSoQob;
  ControlBinop cBinop_jHaVPOqC;
  ControlBinop cBinop_rn43klyD;
  ControlBinop cBinop_UIdQyEPU;
  ControlBinop cBinop_ilRbDb7h;
  SignalVarf sVarf_JViu2CSr;
  ControlBinop cBinop_M6z7g5xz;
  ControlBinop cBinop_kmvuOvQY;
  SignalVarf sVarf_MRkBSpLf;
  SignalVarf sVarf_NZwpsiSR;
  ControlBinop cBinop_EAw8QYCE;
  ControlBinop cBinop_myWN2OBD;
  ControlBinop cBinop_Y4UMDK2U;
  ControlBinop cBinop_VxxJ5ROH;
  ControlBinop cBinop_2eCMCrgq;
  ControlBinop cBinop_NV8X4x17;
  ControlBinop cBinop_R4t0oTAP;
  ControlBinop cBinop_ccqZboCg;
  ControlBinop cBinop_cJ0QiSri;
  ControlBinop cBinop_u1CLaGaa;
  ControlBinop cBinop_szFvVZHb;
  ControlBinop cBinop_HO2QCa8a;
  ControlBinop cBinop_1Kd9C7dh;
};

#endif // _HEAVY_CONTEXT_CHAFFVERB_HPP_
