/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_ChaffVerb.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_ChaffVerb *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_ChaffVerb_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_ChaffVerb();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_ChaffVerb::Heavy_ChaffVerb(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sPhasor_k_init(&sPhasor_5lSPLxw2, 0.0f, sampleRate);
  numBytes += sLine_init(&sLine_j38q5Sh6);
  numBytes += sLine_init(&sLine_F0Jkbzms);
  numBytes += sTabhead_init(&sTabhead_l9WsAcen, &hTable_dkBXVOFZ);
  numBytes += sTabread_init(&sTabread_V1RoKIgy, &hTable_dkBXVOFZ, false);
  numBytes += sTabread_init(&sTabread_TrRonSpA, &hTable_dkBXVOFZ, false);
  numBytes += sTabhead_init(&sTabhead_QTyUkdH9, &hTable_dkBXVOFZ);
  numBytes += sTabread_init(&sTabread_yVuhhqpz, &hTable_dkBXVOFZ, false);
  numBytes += sTabread_init(&sTabread_TaxFNQfy, &hTable_dkBXVOFZ, false);
  numBytes += sTabwrite_init(&sTabwrite_pZJF94pi, &hTable_dkBXVOFZ);
  numBytes += sRPole_init(&sRPole_MDM2KImo);
  numBytes += sDel1_init(&sDel1_UtWig8i2);
  numBytes += sTabread_init(&sTabread_JpZ3w5Mb, &hTable_Pb8JBdIn, true);
  numBytes += sTabwrite_init(&sTabwrite_HWfMrUFA, &hTable_Pb8JBdIn);
  numBytes += sTabread_init(&sTabread_bsqk3m8h, &hTable_WCN6whYK, true);
  numBytes += sRPole_init(&sRPole_hwcpYarA);
  numBytes += sLine_init(&sLine_eJ5jMpbR);
  numBytes += sLine_init(&sLine_ZHE9GDwp);
  numBytes += sTabread_init(&sTabread_oZbqnJdr, &hTable_uzJfL0n7, true);
  numBytes += sTabread_init(&sTabread_KZ0v6kZ2, &hTable_rShBuISs, true);
  numBytes += sTabread_init(&sTabread_xWpkrcHI, &hTable_sqYl8sin, true);
  numBytes += sTabread_init(&sTabread_o9xlsr3h, &hTable_PpWhMVhn, true);
  numBytes += sTabread_init(&sTabread_MqWH9iOI, &hTable_CyQz2ryL, true);
  numBytes += sTabread_init(&sTabread_TTyDYDuZ, &hTable_8TEf7XSC, true);
  numBytes += sTabwrite_init(&sTabwrite_9HVhWerm, &hTable_uzJfL0n7);
  numBytes += sTabwrite_init(&sTabwrite_9NMMb84r, &hTable_rShBuISs);
  numBytes += sTabwrite_init(&sTabwrite_5iV3dFqL, &hTable_sqYl8sin);
  numBytes += sTabwrite_init(&sTabwrite_LeOf7Yvh, &hTable_PpWhMVhn);
  numBytes += sTabwrite_init(&sTabwrite_Hc6xyqzq, &hTable_8TEf7XSC);
  numBytes += sTabwrite_init(&sTabwrite_AwOG3Qk1, &hTable_CyQz2ryL);
  numBytes += sTabread_init(&sTabread_Pf8Caw31, &hTable_LePuUY6p, true);
  numBytes += sRPole_init(&sRPole_EvinB8mB);
  numBytes += sTabread_init(&sTabread_gULkidyi, &hTable_BchNK2H7, true);
  numBytes += sRPole_init(&sRPole_xKnmE4bU);
  numBytes += sTabread_init(&sTabread_7tIINPOS, &hTable_bE9ne5ST, true);
  numBytes += sRPole_init(&sRPole_7hdmz0eI);
  numBytes += sTabwrite_init(&sTabwrite_PgPn9nrj, &hTable_WCN6whYK);
  numBytes += sTabwrite_init(&sTabwrite_9GqrFB3i, &hTable_LePuUY6p);
  numBytes += sTabwrite_init(&sTabwrite_uPKXWkof, &hTable_BchNK2H7);
  numBytes += sTabwrite_init(&sTabwrite_JbR6MEOD, &hTable_bE9ne5ST);
  numBytes += sLine_init(&sLine_pr3NjtZ3);
  numBytes += cVar_init_f(&cVar_j5nvqSJP, 0.0f);
  numBytes += cVar_init_f(&cVar_Y7Mv0xII, 0.0f);
  numBytes += cPack_init(&cPack_GczL4rTy, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_YyHMK2aW, 0.0f);
  numBytes += cPack_init(&cPack_cuEElywh, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_w7x1ePiN, 0.0f);
  numBytes += cVar_init_f(&cVar_gTd7Fn8N, 0.0f);
  numBytes += cDelay_init(this, &cDelay_hYzdihKr, 0.0f);
  numBytes += cDelay_init(this, &cDelay_gzgvYEKy, 0.0f);
  numBytes += hTable_init(&hTable_dkBXVOFZ, 256);
  numBytes += cVar_init_s(&cVar_oVunIFaQ, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_HiQO2z3M, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mkxZFISX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NuTrgtoe, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_OJ359UeV, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_8Fd4WEAn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IpPouE2U, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wxyC3mEu, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_ZmIRzsJZ, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_XzQQSXwW, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_vMxs1m4F, 0.0f);
  numBytes += cBinop_init(&cBinop_I024vmFu, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_zOG8ATgT, 0.0f, 0.0f, false);
  numBytes += cRandom_init(&cRandom_I445K91c, 1901234513);
  numBytes += cSlice_init(&cSlice_GaOwLe9n, 1, 1);
  numBytes += cDelay_init(this, &cDelay_P2cgDwI8, 0.0f);
  numBytes += cVar_init_f(&cVar_L2Ua2viC, 5.0f);
  numBytes += cBinop_init(&cBinop_qSQcgx7O, 0.0f); // __mul
  numBytes += cTabhead_init(&cTabhead_JY6feawi, &hTable_WCN6whYK);
  numBytes += cVar_init_s(&cVar_4AUPQKZB, "del-1052-del1");
  numBytes += cDelay_init(this, &cDelay_0hoMElzM, 58.6435f);
  numBytes += cDelay_init(this, &cDelay_XwAFkPNN, 0.0f);
  numBytes += cBinop_init(&cBinop_XAJhLEJg, 58.6435f); // __mul
  numBytes += cBinop_init(&cBinop_S8ECBZiy, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_7r4BhU4Q, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_g9NVpvVB, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_Zbb23RTW, &hTable_LePuUY6p);
  numBytes += cVar_init_s(&cVar_2WMtqrKQ, "del-1052-del2");
  numBytes += cDelay_init(this, &cDelay_8KN0Dg3F, 69.4325f);
  numBytes += cDelay_init(this, &cDelay_OPZa4J3Q, 0.0f);
  numBytes += cBinop_init(&cBinop_gP5U4Taj, 69.4325f); // __mul
  numBytes += cBinop_init(&cBinop_JjD28HOg, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_tQ1QdvHE, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_2EnGoiPd, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_altUcpBY, &hTable_BchNK2H7);
  numBytes += cVar_init_s(&cVar_Dc0sXUgZ, "del-1052-del3");
  numBytes += cDelay_init(this, &cDelay_kJZCX7Yo, 74.5234f);
  numBytes += cDelay_init(this, &cDelay_Imv1iIVJ, 0.0f);
  numBytes += cBinop_init(&cBinop_0HtiOmUo, 74.5234f); // __mul
  numBytes += cBinop_init(&cBinop_QyMWb2pM, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_mVWCnmZY, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_TN62v8JE, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_iZYtEKa5, &hTable_bE9ne5ST);
  numBytes += cVar_init_s(&cVar_ZDhXYvXv, "del-1052-del4");
  numBytes += cDelay_init(this, &cDelay_wt6vF1mo, 86.1244f);
  numBytes += cDelay_init(this, &cDelay_TJFl8EU3, 0.0f);
  numBytes += cBinop_init(&cBinop_skp5p1Wy, 86.1244f); // __mul
  numBytes += cBinop_init(&cBinop_kTOcaHy5, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_XDDh0rhv, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_PuPYBHKs, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_tw44yydW, 0.0f);
  numBytes += cDelay_init(this, &cDelay_dvHHama0, 0.0f);
  numBytes += hTable_init(&hTable_WCN6whYK, 256);
  numBytes += cDelay_init(this, &cDelay_QfsauD2v, 0.0f);
  numBytes += cDelay_init(this, &cDelay_MsUieQib, 0.0f);
  numBytes += hTable_init(&hTable_LePuUY6p, 256);
  numBytes += cDelay_init(this, &cDelay_1QbVqyH7, 0.0f);
  numBytes += cDelay_init(this, &cDelay_bdmU8f40, 0.0f);
  numBytes += hTable_init(&hTable_BchNK2H7, 256);
  numBytes += cDelay_init(this, &cDelay_iqGGZ5zd, 0.0f);
  numBytes += cDelay_init(this, &cDelay_gVW4yvUQ, 0.0f);
  numBytes += hTable_init(&hTable_bE9ne5ST, 256);
  numBytes += cPack_init(&cPack_qYRkAo8i, 2, 0.0f, 30.0f);
  numBytes += cPack_init(&cPack_D5RCZpEr, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_wtIbebV2, 22050.0f);
  numBytes += cBinop_init(&cBinop_4sq0A6aY, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_vzHyYz4V, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pkqbUEM8, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_8ADDGzmp, 0.0f);
  numBytes += cVar_init_f(&cVar_ha5AksLM, 0.0f);
  numBytes += cVar_init_f(&cVar_8Hw8EnAU, 0.0f);
  numBytes += cVar_init_f(&cVar_4J8Wd9NU, 0.0f);
  numBytes += cIf_init(&cIf_rjrAe9if, false);
  numBytes += cDelay_init(this, &cDelay_Fp0k3ekJ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_bUEzfCmo, 0.0f);
  numBytes += hTable_init(&hTable_uzJfL0n7, 256);
  numBytes += cTabhead_init(&cTabhead_HXqiHGef, &hTable_uzJfL0n7);
  numBytes += cVar_init_s(&cVar_rIKEKlny, "del-1052-ref1");
  numBytes += cDelay_init(this, &cDelay_zcXeCgyB, 43.5337f);
  numBytes += cDelay_init(this, &cDelay_F8SswYZu, 0.0f);
  numBytes += cBinop_init(&cBinop_QOvIwfuL, 43.5337f); // __mul
  numBytes += cBinop_init(&cBinop_oHUAcmjX, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_b2pNDpf3, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_JOXiNK1o, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_6Sg61IJF, 0.0f);
  numBytes += cDelay_init(this, &cDelay_BfN2fuiy, 0.0f);
  numBytes += hTable_init(&hTable_rShBuISs, 256);
  numBytes += cTabhead_init(&cTabhead_BbrRDu9M, &hTable_rShBuISs);
  numBytes += cVar_init_s(&cVar_4nRoI4PF, "del-1052-ref2");
  numBytes += cDelay_init(this, &cDelay_hxIJGdSQ, 25.796f);
  numBytes += cDelay_init(this, &cDelay_pzV5sGDq, 0.0f);
  numBytes += cBinop_init(&cBinop_MMehdqSr, 25.796f); // __mul
  numBytes += cBinop_init(&cBinop_gZEBhVHb, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_ipa22ppI, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_VFrKWMpF, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_E5qzbfDJ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_OtuM2jdA, 0.0f);
  numBytes += hTable_init(&hTable_sqYl8sin, 256);
  numBytes += cTabhead_init(&cTabhead_G3m1a7cE, &hTable_sqYl8sin);
  numBytes += cVar_init_s(&cVar_jd78CtIK, "del-1052-ref3");
  numBytes += cDelay_init(this, &cDelay_eysDd6SZ, 19.392f);
  numBytes += cDelay_init(this, &cDelay_emRYwdNA, 0.0f);
  numBytes += cBinop_init(&cBinop_Y6Rq2u1V, 19.392f); // __mul
  numBytes += cBinop_init(&cBinop_tTcFCjLp, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_aynaolHI, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_5aDP6YJu, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_oZ0eWzZv, 0.0f);
  numBytes += cDelay_init(this, &cDelay_vJWzHppQ, 0.0f);
  numBytes += hTable_init(&hTable_PpWhMVhn, 256);
  numBytes += cTabhead_init(&cTabhead_223ZrU65, &hTable_PpWhMVhn);
  numBytes += cVar_init_s(&cVar_2HlKg5s2, "del-1052-ref4");
  numBytes += cDelay_init(this, &cDelay_nEXUWebE, 16.364f);
  numBytes += cDelay_init(this, &cDelay_LIiALJuS, 0.0f);
  numBytes += cBinop_init(&cBinop_TjDKnMA9, 16.364f); // __mul
  numBytes += cBinop_init(&cBinop_5IrKbHW1, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_Ji3da3ZD, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_L3qyQmz1, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_gwogWSC8, 0.0f);
  numBytes += cDelay_init(this, &cDelay_DFId1suu, 0.0f);
  numBytes += hTable_init(&hTable_8TEf7XSC, 256);
  numBytes += cTabhead_init(&cTabhead_FVQBiQSs, &hTable_8TEf7XSC);
  numBytes += cVar_init_s(&cVar_ta0qCkjA, "del-1052-ref6");
  numBytes += cDelay_init(this, &cDelay_AUe6XDIy, 4.2546f);
  numBytes += cDelay_init(this, &cDelay_6gfGygnV, 0.0f);
  numBytes += cBinop_init(&cBinop_1NhagQTO, 4.2546f); // __mul
  numBytes += cBinop_init(&cBinop_VNmdPpjk, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_sIMzRrzx, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_qlYX83Ic, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_1yWFXi0s, 0.0f);
  numBytes += cDelay_init(this, &cDelay_UwI3G47h, 0.0f);
  numBytes += hTable_init(&hTable_CyQz2ryL, 256);
  numBytes += cTabhead_init(&cTabhead_UIW1LznG, &hTable_CyQz2ryL);
  numBytes += cVar_init_s(&cVar_p3nn0JdC, "del-1052-ref5");
  numBytes += cDelay_init(this, &cDelay_shb9SE1I, 7.645f);
  numBytes += cDelay_init(this, &cDelay_fkt9imvW, 0.0f);
  numBytes += cBinop_init(&cBinop_ce7s3GQr, 7.645f); // __mul
  numBytes += cBinop_init(&cBinop_m4jp1url, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_kkxJC04R, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_rYILDlbK, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_1UWACGH9, 0.0f);
  numBytes += cVar_init_f(&cVar_Z3Aktc3C, 0.0f);
  numBytes += cPack_init(&cPack_aD3N9Uhi, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_lBZRWxTv, 22050.0f);
  numBytes += cBinop_init(&cBinop_YBXa1Rti, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ZtaDrvMv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Znay01cp, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_7EE0Wex0, 22050.0f);
  numBytes += cBinop_init(&cBinop_MNQvS8v1, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_iUcGroED, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vccBUjBq, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_UtcA5vY3, 22050.0f);
  numBytes += cBinop_init(&cBinop_fGQ89Pfb, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_6Tm0cU7G, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QSdT0VTN, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_tGiDF9kU, 0.0f);
  numBytes += cVar_init_f(&cVar_1EA5XEP5, 1000.0f);
  numBytes += cBinop_init(&cBinop_BlXcb0Yv, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_KI2Xa37x, 0.0f);
  numBytes += cVar_init_f(&cVar_59Ervc34, 0.0f);
  numBytes += cIf_init(&cIf_uh0nZfhs, false);
  numBytes += cDelay_init(this, &cDelay_QFiH8UA1, 0.0f);
  numBytes += cDelay_init(this, &cDelay_oWWlS9GR, 0.0f);
  numBytes += hTable_init(&hTable_Pb8JBdIn, 256);
  numBytes += cTabhead_init(&cTabhead_stZ6Ksrm, &hTable_Pb8JBdIn);
  numBytes += cVar_init_s(&cVar_PlRh3U8t, "del-1001-del1");
  numBytes += cDelay_init(this, &cDelay_mQ8D3avh, 150.0f);
  numBytes += cDelay_init(this, &cDelay_PzdMH4p2, 0.0f);
  numBytes += cBinop_init(&cBinop_xFs4Xsgy, 150.0f); // __mul
  numBytes += cBinop_init(&cBinop_EmwJ9Ilb, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_gdEeuN05, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_s6xFKEkw, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_LipFYMTZ, 0.0f);
  numBytes += cVar_init_f(&cVar_rBeE5Hr9, 0.0f);
  numBytes += cVar_init_f(&cVar_sfzs14Gn, 0.0f);
  numBytes += cVar_init_f(&cVar_xqn2TdMI, 0.0f);
  numBytes += cVar_init_f(&cVar_886kD50T, 0.0f);
  numBytes += cVar_init_f(&cVar_m2aktvwy, 0.0f);
  numBytes += cIf_init(&cIf_23yQI59R, false);
  numBytes += cVar_init_f(&cVar_gBK2ClT2, 0.0f);
  numBytes += cIf_init(&cIf_iQ4OMYl6, false);
  numBytes += cSlice_init(&cSlice_mSMNvRM4, 1, -1);
  numBytes += cSlice_init(&cSlice_qubknck7, 1, -1);
  numBytes += cVar_init_f(&cVar_sVcCB2rT, 0.0f);
  numBytes += cIf_init(&cIf_zkzDUhBy, false);
  numBytes += cBinop_init(&cBinop_yMskSg4v, 0.0f); // __neq
  numBytes += cIf_init(&cIf_nMFx0i3X, false);
  numBytes += cIf_init(&cIf_Ea6VEyy4, false);
  numBytes += cIf_init(&cIf_VOjCbw16, false);
  numBytes += cIf_init(&cIf_4CqKjsBB, true);
  numBytes += cIf_init(&cIf_PlbJmkj4, false);
  numBytes += sVarf_init(&sVarf_SEsSoQob, 1.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_UIdQyEPU, 4.0f); // __unimod
  numBytes += sVarf_init(&sVarf_JViu2CSr, 0.1f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_M6z7g5xz, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_kmvuOvQY, 0.0f); // __add
  numBytes += sVarf_init(&sVarf_MRkBSpLf, 0.65f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NZwpsiSR, 0.55f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_myWN2OBD, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_cJ0QiSri, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_u1CLaGaa, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_szFvVZHb, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_HO2QCa8a, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_1Kd9C7dh, 0.0f); // __add
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_ChaffVerb::~Heavy_ChaffVerb() {
  cPack_free(&cPack_GczL4rTy);
  cPack_free(&cPack_cuEElywh);
  hTable_free(&hTable_dkBXVOFZ);
  hTable_free(&hTable_WCN6whYK);
  hTable_free(&hTable_LePuUY6p);
  hTable_free(&hTable_BchNK2H7);
  hTable_free(&hTable_bE9ne5ST);
  cPack_free(&cPack_qYRkAo8i);
  cPack_free(&cPack_D5RCZpEr);
  hTable_free(&hTable_uzJfL0n7);
  hTable_free(&hTable_rShBuISs);
  hTable_free(&hTable_sqYl8sin);
  hTable_free(&hTable_PpWhMVhn);
  hTable_free(&hTable_8TEf7XSC);
  hTable_free(&hTable_CyQz2ryL);
  cPack_free(&cPack_aD3N9Uhi);
  hTable_free(&hTable_Pb8JBdIn);
}

HvTable *Heavy_ChaffVerb::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xA1445E2C: return &hTable_dkBXVOFZ; // del-1002-shifter
    case 0xAAA0EB60: return &hTable_WCN6whYK; // del-1052-del1
    case 0xA2AC524D: return &hTable_LePuUY6p; // del-1052-del2
    case 0xE36A35B: return &hTable_BchNK2H7; // del-1052-del3
    case 0x48CE0509: return &hTable_bE9ne5ST; // del-1052-del4
    case 0xE34D6E72: return &hTable_uzJfL0n7; // del-1052-ref1
    case 0x6A1027AB: return &hTable_rShBuISs; // del-1052-ref2
    case 0xA37C6D49: return &hTable_sqYl8sin; // del-1052-ref3
    case 0xCEFE5FE5: return &hTable_PpWhMVhn; // del-1052-ref4
    case 0x48EB8BBB: return &hTable_8TEf7XSC; // del-1052-ref6
    case 0xCC6F73D5: return &hTable_CyQz2ryL; // del-1052-ref5
    case 0xED65564F: return &hTable_Pb8JBdIn; // del-1001-del1
    default: return nullptr;
  }
}

void Heavy_ChaffVerb::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x1F30993F: { // A__LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sMowLSnf_sendMessage);
      break;
    }
    case 0x1A2B8E9F: { // A__LFO_Steps_Scale__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MkQEhkja_sendMessage);
      break;
    }
    case 0xBE3344C8: { // A__LFO_Steps__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NBXnPyJ7_sendMessage);
      break;
    }
    case 0x7369936E: { // A__LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0Ywf6VDu_sendMessage);
      break;
    }
    case 0xD64CFD23: { // A__LFO_type
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P9PebINy_sendMessage);
      break;
    }
    case 0x51447E19: { // B__General_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2kh2VRtT_sendMessage);
      break;
    }
    case 0xA10FCFC4: { // B__General_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wo4yv7XS_sendMessage);
      break;
    }
    case 0x7EFB8E46: { // C__Random_LFO_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_T3ihUu5s_sendMessage);
      break;
    }
    case 0xE6223016: { // C__Random_LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4XuwuZuI_sendMessage);
      break;
    }
    case 0x3281900D: { // C__Random_LFO_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vWgsNPsL_sendMessage);
      break;
    }
    case 0x6150BC53: { // C__Random_LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VFDVpqBf_sendMessage);
      break;
    }
    case 0x9CBB1BF3: { // D__Shift_Microtone
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HH0uy2ie_sendMessage);
      break;
    }
    case 0x4439D71: { // D__Shift_Transpose
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aOOkkEgo_sendMessage);
      break;
    }
    case 0x890283C2: { // E__Fx_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5NJF82WT_sendMessage);
      break;
    }
    case 0x12962685: { // E__HiPass_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_REytMAWh_sendMessage);
      break;
    }
    case 0x183CFEE5: { // E__Shift_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tN7youEZ_sendMessage);
      break;
    }
    case 0x57FF40DB: { // E__Shift_Window
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_s8dKQ0fH_sendMessage);
      break;
    }
    case 0x69A91334: { // F__FX_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rBtlhfJk_sendMessage);
      break;
    }
    case 0x68D029F7: { // F__FX_Delay_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_O9gKiWdP_sendMessage);
      break;
    }
    case 0xD63693D0: { // Mix__Dry_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3jn2O1Nw_sendMessage);
      break;
    }
    case 0x1FC3C02C: { // Mix__Dry_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QCHDi9vB_sendMessage);
      break;
    }
    case 0x58653D84: { // Mix__Reverb_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sW0RXAIV_sendMessage);
      break;
    }
    case 0xE764F673: { // Mix__Reverb_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gJzdxH30_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9BwMXKXm_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_ChaffVerb::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "A__LFO_Period";
        info->hash = 0x1F30993F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 1: {
        info->name = "A__LFO_Steps_Scale__Type2";
        info->hash = 0x1A2B8E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -5.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "A__LFO_Steps__Type2";
        info->hash = 0xBE3344C8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 10.0f;
        info->defaultVal = 4.0f;
        break;
      }
      case 3: {
        info->name = "A__LFO_Switch";
        info->hash = 0x7369936E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "A__LFO_type";
        info->hash = 0xD64CFD23;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2.99f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "B__General_Offset";
        info->hash = 0x51447E19;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "B__General_Scale";
        info->hash = 0xA10FCFC4;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "C__Random_LFO_Offset";
        info->hash = 0x7EFB8E46;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "C__Random_LFO_Period";
        info->hash = 0xE6223016;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 9: {
        info->name = "C__Random_LFO_Scale";
        info->hash = 0x3281900D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "C__Random_LFO_Switch";
        info->hash = 0x6150BC53;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "D__Shift_Microtone";
        info->hash = 0x9CBB1BF3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -1.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "D__Shift_Transpose";
        info->hash = 0x4439D71;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -36.0f;
        info->maxVal = 36.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "E__Fx_Level";
        info->hash = 0x890283C2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.7f;
        break;
      }
      case 14: {
        info->name = "E__HiPass_Freq";
        info->hash = 0x12962685;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 100.0f;
        info->maxVal = 2500.0f;
        info->defaultVal = 800.0f;
        break;
      }
      case 15: {
        info->name = "E__Shift_Delay";
        info->hash = 0x183CFEE5;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 500.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "E__Shift_Window";
        info->hash = 0x57FF40DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 3500.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 17: {
        info->name = "F__FX_Delay";
        info->hash = 0x69A91334;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 18: {
        info->name = "F__FX_Delay_Feedback";
        info->hash = 0x68D029F7;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.97f;
        info->defaultVal = 0.65f;
        break;
      }
      case 19: {
        info->name = "Mix__Dry_Mix";
        info->hash = 0xD63693D0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.45f;
        break;
      }
      case 20: {
        info->name = "Mix__Dry_Vol";
        info->hash = 0x1FC3C02C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.1f;
        break;
      }
      case 21: {
        info->name = "Mix__Reverb_Level";
        info->hash = 0x58653D84;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.85f;
        break;
      }
      case 22: {
        info->name = "Mix__Reverb_Vol";
        info->hash = 0xE764F673;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.5f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 23;
}



/*
 * Send Function Implementations
 */


void Heavy_ChaffVerb::cVar_j5nvqSJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.05776f, 0, m, &cBinop_jKszPbhK_sendMessage);
}

void Heavy_ChaffVerb::cVar_Y7Mv0xII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_24f1fy54_sendMessage);
}

void Heavy_ChaffVerb::cPack_GczL4rTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_j38q5Sh6, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_Zp57mptB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YyHMK2aW, 0, m, &cVar_YyHMK2aW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DLtlM46D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_EXP, m, &cUnop_Zp57mptB_sendMessage);
}

void Heavy_ChaffVerb::cVar_YyHMK2aW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_MXNaulKQ_sendMessage);
}

void Heavy_ChaffVerb::cPack_cuEElywh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_F0Jkbzms, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_w7x1ePiN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.5f, 0, m, &cBinop_HQ45Yv1z_sendMessage);
}

void Heavy_ChaffVerb::cVar_gTd7Fn8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_5lSPLxw2, 0, m);
}

void Heavy_ChaffVerb::cMsg_82nEWbyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Bu0OUJX5_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Bu0OUJX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_w17LqwBp_sendMessage);
}

void Heavy_ChaffVerb::cDelay_hYzdihKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hYzdihKr, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gzgvYEKy, 0, m, &cDelay_gzgvYEKy_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hYzdihKr, 0, m, &cDelay_hYzdihKr_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_pZJF94pi, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_gzgvYEKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gzgvYEKy, m);
  cMsg_kxKz7D6N_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_W2UaS4hN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_YxPC6dK8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_T82ydbjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eKi7vHri_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_dkBXVOFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CJu9g727_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hYzdihKr, 2, m, &cDelay_hYzdihKr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q2i10ki5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_eKi7vHri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_dkBXVOFZ, 0, m, &hTable_dkBXVOFZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_w17LqwBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_T82ydbjn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kxKz7D6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_dkBXVOFZ, 0, m, &hTable_dkBXVOFZ_sendMessage);
}

void Heavy_ChaffVerb::cCast_q2i10ki5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hYzdihKr, 0, m, &cDelay_hYzdihKr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CJu9g727_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_gzgvYEKy, 2, m, &cDelay_gzgvYEKy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YxPC6dK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_pZJF94pi, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_qgCXF2IX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8UGELcJV_sendMessage);
}

void Heavy_ChaffVerb::cSystem_8UGELcJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Ftm2kpri_sendMessage);
}

void Heavy_ChaffVerb::cVar_oVunIFaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NUKILwVC_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_A8zVkXWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_3bdFOm63_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_HiQO2z3M, m);
}

void Heavy_ChaffVerb::cBinop_Ftm2kpri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_mkxZFISX, m);
}

void Heavy_ChaffVerb::cMsg_NUKILwVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_A8zVkXWq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3bdFOm63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_NuTrgtoe, m);
}

void Heavy_ChaffVerb::cMsg_N60Ixq33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oSZsxJvM_sendMessage);
}

void Heavy_ChaffVerb::cSystem_oSZsxJvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_0e0JzboO_sendMessage);
}

void Heavy_ChaffVerb::cVar_OJ359UeV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W8bEwQto_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_XhgASOXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ZTTMx9Yx_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_8Fd4WEAn, m);
}

void Heavy_ChaffVerb::cBinop_0e0JzboO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_IpPouE2U, m);
}

void Heavy_ChaffVerb::cMsg_W8bEwQto_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XhgASOXS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZTTMx9Yx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_wxyC3mEu, m);
}

void Heavy_ChaffVerb::cBinop_ZmIRzsJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gTd7Fn8N, 0, m, &cVar_gTd7Fn8N_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8yrdlRvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HUTuZCpw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SmCvvjxG_sendMessage);
}

void Heavy_ChaffVerb::cCast_HUTuZCpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZmIRzsJZ, HV_BINOP_DIVIDE, 1, m, &cBinop_ZmIRzsJZ_sendMessage);
}

void Heavy_ChaffVerb::cCast_SmCvvjxG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZmIRzsJZ, HV_BINOP_DIVIDE, 0, m, &cBinop_ZmIRzsJZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MXNaulKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_AgAtVmSa_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jKszPbhK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 87.3365f, 0, m, &cBinop_DLtlM46D_sendMessage);
}

void Heavy_ChaffVerb::cBinop_AgAtVmSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZmIRzsJZ, HV_BINOP_DIVIDE, 0, m, &cBinop_ZmIRzsJZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HQ45Yv1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_cuEElywh, 0, m, &cPack_cuEElywh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_24f1fy54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.001f, 0, m, &cBinop_8yrdlRvT_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_GczL4rTy, 0, m, &cPack_GczL4rTy_sendMessage);
}

void Heavy_ChaffVerb::cUnop_a6zmeojr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ea6VEyy4, 0, m, &cIf_Ea6VEyy4_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_LjEx9g3G_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pTS9qXd1_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Yem3Ly6T_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w8lVIh0c_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_pTS9qXd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r7vU22kH_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_Yem3Ly6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K1c2mgbW_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_w8lVIh0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xRrZUycG_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_vZwPIPUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_3JV5IYMv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3JV5IYMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_X8kBlean_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ZvnlX7QI_sendMessage);
}

void Heavy_ChaffVerb::cVar_vMxs1m4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_UluI8Bf0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lp2NgwuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KqoFg9o5_sendMessage);
}

void Heavy_ChaffVerb::cSystem_KqoFg9o5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I024vmFu, HV_BINOP_DIVIDE, 1, m, &cBinop_I024vmFu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_X8kBlean_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uwEFkceL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_uwEFkceL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_zOG8ATgT, m);
}

void Heavy_ChaffVerb::cMsg_RnyTzVpv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_0S0N00Ig_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0S0N00Ig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vZwPIPUL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZvnlX7QI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XzQQSXwW, m);
}

void Heavy_ChaffVerb::cBinop_UluI8Bf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_gX4SYFPR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gX4SYFPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I024vmFu, HV_BINOP_DIVIDE, 0, m, &cBinop_I024vmFu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_I024vmFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RnyTzVpv_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_RN8hSmWc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7E64BD01: { // "seed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GaOwLe9n, 0, m, &cSlice_GaOwLe9n_sendMessage);
      break;
    }
    default: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_I445K91c, 0, m, &cRandom_I445K91c_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_VHoy4jx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_GAyJNwSQ_sendMessage);
}

void Heavy_ChaffVerb::cUnop_GAyJNwSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 50.0f, 0, m, &cBinop_rn43klyD_sendMessage);
}

void Heavy_ChaffVerb::cRandom_I445K91c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_VHoy4jx8_sendMessage);
}

void Heavy_ChaffVerb::cSlice_GaOwLe9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_I445K91c, 1, m, &cRandom_I445K91c_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSwitchcase_1AynuYoS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_CIfctNYt_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_CIfctNYt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QelQapNG_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_P2cgDwI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_P2cgDwI8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_P2cgDwI8, 0, m, &cDelay_P2cgDwI8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KI2Xa37x, 0, m, &cVar_KI2Xa37x_sendMessage);
}

void Heavy_ChaffVerb::cCast_QelQapNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CIfctNYt_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_P2cgDwI8, 0, m, &cDelay_P2cgDwI8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KI2Xa37x, 0, m, &cVar_KI2Xa37x_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DcRVp6kE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hTxV92Ut_sendMessage);
}

void Heavy_ChaffVerb::cSystem_hTxV92Ut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_VQSg6Y38_sendMessage);
}

void Heavy_ChaffVerb::cVar_L2Ua2viC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qSQcgx7O, HV_BINOP_MULTIPLY, 0, m, &cBinop_qSQcgx7O_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CIfctNYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_P2cgDwI8, 0, m, &cDelay_P2cgDwI8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7yNC17Ad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_P2cgDwI8, 2, m, &cDelay_P2cgDwI8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VQSg6Y38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qSQcgx7O, HV_BINOP_MULTIPLY, 1, m, &cBinop_qSQcgx7O_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qSQcgx7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_7yNC17Ad_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_JY6feawi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_S8ECBZiy, HV_BINOP_SUBTRACT, 0, m, &cBinop_S8ECBZiy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6I4sTYfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dzskrm20_sendMessage);
}

void Heavy_ChaffVerb::cSystem_dzskrm20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_SwVlYJTP_sendMessage);
}

void Heavy_ChaffVerb::cVar_4AUPQKZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3eVVsNF7_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_0hoMElzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0hoMElzM, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XwAFkPNN, 0, m, &cDelay_XwAFkPNN_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_bsqk3m8h, 0, m, &sTabread_bsqk3m8h_sendMessage);
}

void Heavy_ChaffVerb::cDelay_XwAFkPNN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XwAFkPNN, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_bsqk3m8h, 0, m, &sTabread_bsqk3m8h_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XwAFkPNN, 0, m, &cDelay_XwAFkPNN_sendMessage);
}

void Heavy_ChaffVerb::sTabread_bsqk3m8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_g9NVpvVB, HV_BINOP_SUBTRACT, 0, m, &cBinop_g9NVpvVB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_XAJhLEJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7r4BhU4Q, HV_BINOP_MAX, 0, m, &cBinop_7r4BhU4Q_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SwVlYJTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XAJhLEJg, HV_BINOP_MULTIPLY, 0, m, &cBinop_XAJhLEJg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_S8ECBZiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_En7wzmvI_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_bsqk3m8h, 0, m, &sTabread_bsqk3m8h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ysc9To9E_sendMessage);
}

void Heavy_ChaffVerb::cSystem_7KAI1o9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g9NVpvVB, HV_BINOP_SUBTRACT, 1, m, &cBinop_g9NVpvVB_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XwAFkPNN, 2, m, &cDelay_XwAFkPNN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3eVVsNF7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7KAI1o9m_sendMessage);
}

void Heavy_ChaffVerb::cMsg_En7wzmvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0hoMElzM, 0, m, &cDelay_0hoMElzM_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XwAFkPNN, 0, m, &cDelay_XwAFkPNN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CPPqI6mb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_7r4BhU4Q, HV_BINOP_MAX, 1, m, &cBinop_7r4BhU4Q_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7r4BhU4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_S8ECBZiy, HV_BINOP_SUBTRACT, 1, m, &cBinop_S8ECBZiy_sendMessage);
}

void Heavy_ChaffVerb::cCast_Ysc9To9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0hoMElzM, 0, m, &cDelay_0hoMElzM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0FPOfYSm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0hoMElzM, 2, m, &cDelay_0hoMElzM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_g9NVpvVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_0FPOfYSm_sendMessage);
}

void Heavy_ChaffVerb::cCast_IyGbaZ4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4AUPQKZB, 0, m, &cVar_4AUPQKZB_sendMessage);
  cMsg_6I4sTYfX_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_JY6feawi, 0, m, &cTabhead_JY6feawi_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_Zbb23RTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JjD28HOg, HV_BINOP_SUBTRACT, 0, m, &cBinop_JjD28HOg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iDubDUz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jaSaMo3r_sendMessage);
}

void Heavy_ChaffVerb::cSystem_jaSaMo3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_sZOV2VTh_sendMessage);
}

void Heavy_ChaffVerb::cVar_2WMtqrKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hoFhcE6b_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_8KN0Dg3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8KN0Dg3F, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OPZa4J3Q, 0, m, &cDelay_OPZa4J3Q_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Pf8Caw31, 0, m, &sTabread_Pf8Caw31_sendMessage);
}

void Heavy_ChaffVerb::cDelay_OPZa4J3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OPZa4J3Q, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Pf8Caw31, 0, m, &sTabread_Pf8Caw31_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OPZa4J3Q, 0, m, &cDelay_OPZa4J3Q_sendMessage);
}

void Heavy_ChaffVerb::sTabread_Pf8Caw31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_2EnGoiPd, HV_BINOP_SUBTRACT, 0, m, &cBinop_2EnGoiPd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_gP5U4Taj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tQ1QdvHE, HV_BINOP_MAX, 0, m, &cBinop_tQ1QdvHE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sZOV2VTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gP5U4Taj, HV_BINOP_MULTIPLY, 0, m, &cBinop_gP5U4Taj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JjD28HOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_76O8oXzv_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Pf8Caw31, 0, m, &sTabread_Pf8Caw31_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9DhbiYr7_sendMessage);
}

void Heavy_ChaffVerb::cSystem_EVL70ujK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2EnGoiPd, HV_BINOP_SUBTRACT, 1, m, &cBinop_2EnGoiPd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OPZa4J3Q, 2, m, &cDelay_OPZa4J3Q_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hoFhcE6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EVL70ujK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_76O8oXzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8KN0Dg3F, 0, m, &cDelay_8KN0Dg3F_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OPZa4J3Q, 0, m, &cDelay_OPZa4J3Q_sendMessage);
}

void Heavy_ChaffVerb::cMsg_s51VwQUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_tQ1QdvHE, HV_BINOP_MAX, 1, m, &cBinop_tQ1QdvHE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tQ1QdvHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JjD28HOg, HV_BINOP_SUBTRACT, 1, m, &cBinop_JjD28HOg_sendMessage);
}

void Heavy_ChaffVerb::cCast_9DhbiYr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8KN0Dg3F, 0, m, &cDelay_8KN0Dg3F_sendMessage);
}

void Heavy_ChaffVerb::cBinop_aYwsKlhO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8KN0Dg3F, 2, m, &cDelay_8KN0Dg3F_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2EnGoiPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_aYwsKlhO_sendMessage);
}

void Heavy_ChaffVerb::cCast_U12EJciL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2WMtqrKQ, 0, m, &cVar_2WMtqrKQ_sendMessage);
  cMsg_iDubDUz7_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Zbb23RTW, 0, m, &cTabhead_Zbb23RTW_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_altUcpBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QyMWb2pM, HV_BINOP_SUBTRACT, 0, m, &cBinop_QyMWb2pM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mCawOMRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fVr3SrlU_sendMessage);
}

void Heavy_ChaffVerb::cSystem_fVr3SrlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_lq0z28OQ_sendMessage);
}

void Heavy_ChaffVerb::cVar_Dc0sXUgZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9KYrrfGz_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_kJZCX7Yo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kJZCX7Yo, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Imv1iIVJ, 0, m, &cDelay_Imv1iIVJ_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gULkidyi, 0, m, &sTabread_gULkidyi_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Imv1iIVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Imv1iIVJ, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gULkidyi, 0, m, &sTabread_gULkidyi_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Imv1iIVJ, 0, m, &cDelay_Imv1iIVJ_sendMessage);
}

void Heavy_ChaffVerb::sTabread_gULkidyi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_TN62v8JE, HV_BINOP_SUBTRACT, 0, m, &cBinop_TN62v8JE_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_0HtiOmUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mVWCnmZY, HV_BINOP_MAX, 0, m, &cBinop_mVWCnmZY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lq0z28OQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0HtiOmUo, HV_BINOP_MULTIPLY, 0, m, &cBinop_0HtiOmUo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QyMWb2pM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O9rd20k3_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gULkidyi, 0, m, &sTabread_gULkidyi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fC3HXrwn_sendMessage);
}

void Heavy_ChaffVerb::cSystem_CQeQNXJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TN62v8JE, HV_BINOP_SUBTRACT, 1, m, &cBinop_TN62v8JE_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Imv1iIVJ, 2, m, &cDelay_Imv1iIVJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9KYrrfGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CQeQNXJO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_O9rd20k3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kJZCX7Yo, 0, m, &cDelay_kJZCX7Yo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Imv1iIVJ, 0, m, &cDelay_Imv1iIVJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rvlX9iTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_mVWCnmZY, HV_BINOP_MAX, 1, m, &cBinop_mVWCnmZY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mVWCnmZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QyMWb2pM, HV_BINOP_SUBTRACT, 1, m, &cBinop_QyMWb2pM_sendMessage);
}

void Heavy_ChaffVerb::cCast_fC3HXrwn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kJZCX7Yo, 0, m, &cDelay_kJZCX7Yo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Cg6MhJWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kJZCX7Yo, 2, m, &cDelay_kJZCX7Yo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TN62v8JE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Cg6MhJWd_sendMessage);
}

void Heavy_ChaffVerb::cCast_Ki4WfTm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Dc0sXUgZ, 0, m, &cVar_Dc0sXUgZ_sendMessage);
  cMsg_mCawOMRv_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_altUcpBY, 0, m, &cTabhead_altUcpBY_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_iZYtEKa5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kTOcaHy5, HV_BINOP_SUBTRACT, 0, m, &cBinop_kTOcaHy5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_efUGlpnc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pyuypEiC_sendMessage);
}

void Heavy_ChaffVerb::cSystem_pyuypEiC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_xFjN9nVy_sendMessage);
}

void Heavy_ChaffVerb::cVar_ZDhXYvXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q1L3Zc0k_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_wt6vF1mo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wt6vF1mo, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TJFl8EU3, 0, m, &cDelay_TJFl8EU3_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_7tIINPOS, 0, m, &sTabread_7tIINPOS_sendMessage);
}

void Heavy_ChaffVerb::cDelay_TJFl8EU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TJFl8EU3, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_7tIINPOS, 0, m, &sTabread_7tIINPOS_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TJFl8EU3, 0, m, &cDelay_TJFl8EU3_sendMessage);
}

void Heavy_ChaffVerb::sTabread_7tIINPOS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_PuPYBHKs, HV_BINOP_SUBTRACT, 0, m, &cBinop_PuPYBHKs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_skp5p1Wy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XDDh0rhv, HV_BINOP_MAX, 0, m, &cBinop_XDDh0rhv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xFjN9nVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_skp5p1Wy, HV_BINOP_MULTIPLY, 0, m, &cBinop_skp5p1Wy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kTOcaHy5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MnCPDe7N_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_7tIINPOS, 0, m, &sTabread_7tIINPOS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a5R0IEZO_sendMessage);
}

void Heavy_ChaffVerb::cSystem_7QCdPwDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PuPYBHKs, HV_BINOP_SUBTRACT, 1, m, &cBinop_PuPYBHKs_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TJFl8EU3, 2, m, &cDelay_TJFl8EU3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Q1L3Zc0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7QCdPwDl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MnCPDe7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wt6vF1mo, 0, m, &cDelay_wt6vF1mo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TJFl8EU3, 0, m, &cDelay_TJFl8EU3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TiR7qfTT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_XDDh0rhv, HV_BINOP_MAX, 1, m, &cBinop_XDDh0rhv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XDDh0rhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kTOcaHy5, HV_BINOP_SUBTRACT, 1, m, &cBinop_kTOcaHy5_sendMessage);
}

void Heavy_ChaffVerb::cCast_a5R0IEZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wt6vF1mo, 0, m, &cDelay_wt6vF1mo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gCJXplcu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wt6vF1mo, 2, m, &cDelay_wt6vF1mo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PuPYBHKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_gCJXplcu_sendMessage);
}

void Heavy_ChaffVerb::cCast_m1Fwvt22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZDhXYvXv, 0, m, &cVar_ZDhXYvXv_sendMessage);
  cMsg_efUGlpnc_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_iZYtEKa5, 0, m, &cTabhead_iZYtEKa5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_I5ki9PAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DrDMk2Ec_sendMessage);
}

void Heavy_ChaffVerb::cSystem_DrDMk2Ec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_P49zYBbb_sendMessage);
}

void Heavy_ChaffVerb::cDelay_tw44yydW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tw44yydW, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dvHHama0, 0, m, &cDelay_dvHHama0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tw44yydW, 0, m, &cDelay_tw44yydW_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_PgPn9nrj, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_dvHHama0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dvHHama0, m);
  cMsg_TkuFnmOy_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_SnBzZhZB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_wvRD3n7H_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_SMTViuja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f4Y4e5b2_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_WCN6whYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NFhF36Pj_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tw44yydW, 2, m, &cDelay_tw44yydW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2zY8tmyg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_f4Y4e5b2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_WCN6whYK, 0, m, &hTable_WCN6whYK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_P49zYBbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 58.6435f, 0, m, &cBinop_SMTViuja_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TkuFnmOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_WCN6whYK, 0, m, &hTable_WCN6whYK_sendMessage);
}

void Heavy_ChaffVerb::cCast_2zY8tmyg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tw44yydW, 0, m, &cDelay_tw44yydW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NFhF36Pj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_dvHHama0, 2, m, &cDelay_dvHHama0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wvRD3n7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_PgPn9nrj, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_bWPVsmmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_R04u5wWx_sendMessage);
}

void Heavy_ChaffVerb::cSystem_R04u5wWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_thWVPBIE_sendMessage);
}

void Heavy_ChaffVerb::cDelay_QfsauD2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QfsauD2v, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MsUieQib, 0, m, &cDelay_MsUieQib_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QfsauD2v, 0, m, &cDelay_QfsauD2v_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9GqrFB3i, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_MsUieQib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MsUieQib, m);
  cMsg_XgCc8avo_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_v6lDltmB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_OgYZzvsM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_34Xk0nNl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HAOMk4Xu_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_LePuUY6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rgRzWQOA_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QfsauD2v, 2, m, &cDelay_QfsauD2v_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H4RAtANo_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HAOMk4Xu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_LePuUY6p, 0, m, &hTable_LePuUY6p_sendMessage);
}

void Heavy_ChaffVerb::cBinop_thWVPBIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 69.4325f, 0, m, &cBinop_34Xk0nNl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XgCc8avo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_LePuUY6p, 0, m, &hTable_LePuUY6p_sendMessage);
}

void Heavy_ChaffVerb::cCast_H4RAtANo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QfsauD2v, 0, m, &cDelay_QfsauD2v_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rgRzWQOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_MsUieQib, 2, m, &cDelay_MsUieQib_sendMessage);
}

void Heavy_ChaffVerb::cMsg_OgYZzvsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9GqrFB3i, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_3rtlKPzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ssMBg8tv_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ssMBg8tv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_jHolRwr1_sendMessage);
}

void Heavy_ChaffVerb::cDelay_1QbVqyH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1QbVqyH7, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bdmU8f40, 0, m, &cDelay_bdmU8f40_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1QbVqyH7, 0, m, &cDelay_1QbVqyH7_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_uPKXWkof, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_bdmU8f40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bdmU8f40, m);
  cMsg_CVr09vOA_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_HwvlsSsF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_AONCR0A8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_o1Uu6Akz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i7UYoUCF_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_BchNK2H7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QI4Kak8c_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1QbVqyH7, 2, m, &cDelay_1QbVqyH7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4WThvooa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_i7UYoUCF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_BchNK2H7, 0, m, &hTable_BchNK2H7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jHolRwr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 74.5234f, 0, m, &cBinop_o1Uu6Akz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CVr09vOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_BchNK2H7, 0, m, &hTable_BchNK2H7_sendMessage);
}

void Heavy_ChaffVerb::cCast_4WThvooa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1QbVqyH7, 0, m, &cDelay_1QbVqyH7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QI4Kak8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_bdmU8f40, 2, m, &cDelay_bdmU8f40_sendMessage);
}

void Heavy_ChaffVerb::cMsg_AONCR0A8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_uPKXWkof, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_QmJa2Shl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9XjGhMwz_sendMessage);
}

void Heavy_ChaffVerb::cSystem_9XjGhMwz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_rCoPap82_sendMessage);
}

void Heavy_ChaffVerb::cDelay_iqGGZ5zd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_iqGGZ5zd, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gVW4yvUQ, 0, m, &cDelay_gVW4yvUQ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iqGGZ5zd, 0, m, &cDelay_iqGGZ5zd_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_JbR6MEOD, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_gVW4yvUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gVW4yvUQ, m);
  cMsg_rmH0W9KV_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_mwPv5qnn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_omRuSjb1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_Jgreo8nv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TMpTiQ9U_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_bE9ne5ST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b4ghMUyN_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iqGGZ5zd, 2, m, &cDelay_iqGGZ5zd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Kkq1RBmE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TMpTiQ9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_bE9ne5ST, 0, m, &hTable_bE9ne5ST_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rCoPap82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 86.1244f, 0, m, &cBinop_Jgreo8nv_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rmH0W9KV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_bE9ne5ST, 0, m, &hTable_bE9ne5ST_sendMessage);
}

void Heavy_ChaffVerb::cCast_Kkq1RBmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_iqGGZ5zd, 0, m, &cDelay_iqGGZ5zd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_b4ghMUyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_gVW4yvUQ, 2, m, &cDelay_gVW4yvUQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_omRuSjb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_JbR6MEOD, 1, m, NULL);
}

void Heavy_ChaffVerb::cPack_qYRkAo8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_pr3NjtZ3, 0, m, NULL);
}

void Heavy_ChaffVerb::cPack_D5RCZpEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_ZHE9GDwp, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_oUbUxb6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_KtWOfnUU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_KtWOfnUU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 200.0f, 0, m, &cBinop_oP6RWEWU_sendMessage);
}

void Heavy_ChaffVerb::cVar_wtIbebV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4sq0A6aY, HV_BINOP_MULTIPLY, 0, m, &cBinop_4sq0A6aY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zybmaf4i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_I9QPPgYH_sendMessage);
}

void Heavy_ChaffVerb::cSystem_I9QPPgYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e0CbgBS9_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_4sq0A6aY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hU0VZVni_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OV1yP2zv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4sq0A6aY, HV_BINOP_MULTIPLY, 1, m, &cBinop_4sq0A6aY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_e0CbgBS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_OV1yP2zv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hU0VZVni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_zwzaN8rh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zwzaN8rh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_jjJG6llo_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_pkqbUEM8, m);
}

void Heavy_ChaffVerb::cBinop_jjJG6llo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_vzHyYz4V, m);
}

void Heavy_ChaffVerb::cVar_8ADDGzmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.125f, 0, m, &cBinop_5GUuDzAS_sendMessage);
}

void Heavy_ChaffVerb::cVar_ha5AksLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_oUbUxb6d_sendMessage);
}

void Heavy_ChaffVerb::cVar_8Hw8EnAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN_EQL, 1.0f, 0, m, &cBinop_OSIodmVs_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_rjrAe9if, 0, m, &cIf_rjrAe9if_sendMessage);
}

void Heavy_ChaffVerb::cVar_4J8Wd9NU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_i8i7FGbR_sendMessage);
}

void Heavy_ChaffVerb::cIf_rjrAe9if_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_D0umbA5h_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_1UWACGH9, 0, m, &cVar_1UWACGH9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_OSIodmVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rjrAe9if, 1, m, &cIf_rjrAe9if_sendMessage);
}

void Heavy_ChaffVerb::cBinop_i8i7FGbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_DViR7tDZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DViR7tDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z3Aktc3C, 0, m, &cVar_Z3Aktc3C_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iNBB7xBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1R8nV73E_sendMessage);
}

void Heavy_ChaffVerb::cSystem_1R8nV73E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_coXsF9b4_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Fp0k3ekJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Fp0k3ekJ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bUEzfCmo, 0, m, &cDelay_bUEzfCmo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Fp0k3ekJ, 0, m, &cDelay_Fp0k3ekJ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9HVhWerm, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_bUEzfCmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bUEzfCmo, m);
  cMsg_76Al9vAu_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_9GuVojHv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_FFvrHTT8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_xKIBhOeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GQDYwYYo_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_uzJfL0n7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jUnSelrn_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Fp0k3ekJ, 2, m, &cDelay_Fp0k3ekJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lO1Dfpdm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GQDYwYYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_uzJfL0n7, 0, m, &hTable_uzJfL0n7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_coXsF9b4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 43.5337f, 0, m, &cBinop_xKIBhOeI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_76Al9vAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_uzJfL0n7, 0, m, &hTable_uzJfL0n7_sendMessage);
}

void Heavy_ChaffVerb::cCast_lO1Dfpdm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Fp0k3ekJ, 0, m, &cDelay_Fp0k3ekJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jUnSelrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_bUEzfCmo, 2, m, &cDelay_bUEzfCmo_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FFvrHTT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9HVhWerm, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_HXqiHGef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oHUAcmjX, HV_BINOP_SUBTRACT, 0, m, &cBinop_oHUAcmjX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_WeG10SZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Y06H89fu_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Y06H89fu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_IZe9dsgb_sendMessage);
}

void Heavy_ChaffVerb::cVar_rIKEKlny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OrwjBpPo_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_zcXeCgyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zcXeCgyB, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_F8SswYZu, 0, m, &cDelay_F8SswYZu_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_oZbqnJdr, 0, m, &sTabread_oZbqnJdr_sendMessage);
}

void Heavy_ChaffVerb::cDelay_F8SswYZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_F8SswYZu, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_oZbqnJdr, 0, m, &sTabread_oZbqnJdr_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_F8SswYZu, 0, m, &cDelay_F8SswYZu_sendMessage);
}

void Heavy_ChaffVerb::sTabread_oZbqnJdr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_JOXiNK1o, HV_BINOP_SUBTRACT, 0, m, &cBinop_JOXiNK1o_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_QOvIwfuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b2pNDpf3, HV_BINOP_MAX, 0, m, &cBinop_b2pNDpf3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IZe9dsgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QOvIwfuL, HV_BINOP_MULTIPLY, 0, m, &cBinop_QOvIwfuL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_oHUAcmjX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hANhUuAh_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_oZbqnJdr, 0, m, &sTabread_oZbqnJdr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jnAPQmvC_sendMessage);
}

void Heavy_ChaffVerb::cSystem_xiDTRnK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JOXiNK1o, HV_BINOP_SUBTRACT, 1, m, &cBinop_JOXiNK1o_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_F8SswYZu, 2, m, &cDelay_F8SswYZu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_OrwjBpPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xiDTRnK7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hANhUuAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zcXeCgyB, 0, m, &cDelay_zcXeCgyB_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_F8SswYZu, 0, m, &cDelay_F8SswYZu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5jFx4EkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_b2pNDpf3, HV_BINOP_MAX, 1, m, &cBinop_b2pNDpf3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_b2pNDpf3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oHUAcmjX, HV_BINOP_SUBTRACT, 1, m, &cBinop_oHUAcmjX_sendMessage);
}

void Heavy_ChaffVerb::cCast_jnAPQmvC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zcXeCgyB, 0, m, &cDelay_zcXeCgyB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0sLpJRym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zcXeCgyB, 2, m, &cDelay_zcXeCgyB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JOXiNK1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_0sLpJRym_sendMessage);
}

void Heavy_ChaffVerb::cCast_Svq6ntMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rIKEKlny, 0, m, &cVar_rIKEKlny_sendMessage);
  cMsg_WeG10SZN_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_HXqiHGef, 0, m, &cTabhead_HXqiHGef_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JYqGiHaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_erAhIe7R_sendMessage);
}

void Heavy_ChaffVerb::cSystem_erAhIe7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_HUnmW31y_sendMessage);
}

void Heavy_ChaffVerb::cDelay_6Sg61IJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6Sg61IJF, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BfN2fuiy, 0, m, &cDelay_BfN2fuiy_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6Sg61IJF, 0, m, &cDelay_6Sg61IJF_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9NMMb84r, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_BfN2fuiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BfN2fuiy, m);
  cMsg_k5NUVBwB_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_Vpl9O388_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_SilGNlpU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_34Dl9E0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Qzasq3Ju_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_rShBuISs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dkkV6PEe_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6Sg61IJF, 2, m, &cDelay_6Sg61IJF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jodJLHBx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Qzasq3Ju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_rShBuISs, 0, m, &hTable_rShBuISs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HUnmW31y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 25.796f, 0, m, &cBinop_34Dl9E0u_sendMessage);
}

void Heavy_ChaffVerb::cMsg_k5NUVBwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_rShBuISs, 0, m, &hTable_rShBuISs_sendMessage);
}

void Heavy_ChaffVerb::cCast_jodJLHBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6Sg61IJF, 0, m, &cDelay_6Sg61IJF_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dkkV6PEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_BfN2fuiy, 2, m, &cDelay_BfN2fuiy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SilGNlpU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9NMMb84r, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_BbrRDu9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gZEBhVHb, HV_BINOP_SUBTRACT, 0, m, &cBinop_gZEBhVHb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Oq62Enkl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EhHOlZhe_sendMessage);
}

void Heavy_ChaffVerb::cSystem_EhHOlZhe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_geECz5Gu_sendMessage);
}

void Heavy_ChaffVerb::cVar_4nRoI4PF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I71AokXo_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_hxIJGdSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hxIJGdSQ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pzV5sGDq, 0, m, &cDelay_pzV5sGDq_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_KZ0v6kZ2, 0, m, &sTabread_KZ0v6kZ2_sendMessage);
}

void Heavy_ChaffVerb::cDelay_pzV5sGDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pzV5sGDq, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_KZ0v6kZ2, 0, m, &sTabread_KZ0v6kZ2_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pzV5sGDq, 0, m, &cDelay_pzV5sGDq_sendMessage);
}

void Heavy_ChaffVerb::sTabread_KZ0v6kZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_VFrKWMpF, HV_BINOP_SUBTRACT, 0, m, &cBinop_VFrKWMpF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_MMehdqSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ipa22ppI, HV_BINOP_MAX, 0, m, &cBinop_ipa22ppI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_geECz5Gu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MMehdqSr, HV_BINOP_MULTIPLY, 0, m, &cBinop_MMehdqSr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gZEBhVHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hZMfL9bZ_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_KZ0v6kZ2, 0, m, &sTabread_KZ0v6kZ2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0O1qlohm_sendMessage);
}

void Heavy_ChaffVerb::cSystem_0srMnz6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VFrKWMpF, HV_BINOP_SUBTRACT, 1, m, &cBinop_VFrKWMpF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pzV5sGDq, 2, m, &cDelay_pzV5sGDq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_I71AokXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0srMnz6I_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hZMfL9bZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hxIJGdSQ, 0, m, &cDelay_hxIJGdSQ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pzV5sGDq, 0, m, &cDelay_pzV5sGDq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xld6Pxy3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_ipa22ppI, HV_BINOP_MAX, 1, m, &cBinop_ipa22ppI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ipa22ppI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gZEBhVHb, HV_BINOP_SUBTRACT, 1, m, &cBinop_gZEBhVHb_sendMessage);
}

void Heavy_ChaffVerb::cCast_0O1qlohm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hxIJGdSQ, 0, m, &cDelay_hxIJGdSQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qWGHmhTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hxIJGdSQ, 2, m, &cDelay_hxIJGdSQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VFrKWMpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_qWGHmhTh_sendMessage);
}

void Heavy_ChaffVerb::cCast_PkaARKgy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4nRoI4PF, 0, m, &cVar_4nRoI4PF_sendMessage);
  cMsg_Oq62Enkl_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_BbrRDu9M, 0, m, &cTabhead_BbrRDu9M_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hAdeH2CU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_k2vAzLiv_sendMessage);
}

void Heavy_ChaffVerb::cSystem_k2vAzLiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9xKcOWZB_sendMessage);
}

void Heavy_ChaffVerb::cDelay_E5qzbfDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_E5qzbfDJ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OtuM2jdA, 0, m, &cDelay_OtuM2jdA_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_E5qzbfDJ, 0, m, &cDelay_E5qzbfDJ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_5iV3dFqL, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_OtuM2jdA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OtuM2jdA, m);
  cMsg_YfxK1Pb0_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_0ZcOcn40_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_dMBMGj12_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_BpSwpKBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8NRQLwtL_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_sqYl8sin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HV81fptC_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_E5qzbfDJ, 2, m, &cDelay_E5qzbfDJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JgVAna10_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8NRQLwtL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_sqYl8sin, 0, m, &hTable_sqYl8sin_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9xKcOWZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 19.392f, 0, m, &cBinop_BpSwpKBh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YfxK1Pb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_sqYl8sin, 0, m, &hTable_sqYl8sin_sendMessage);
}

void Heavy_ChaffVerb::cCast_JgVAna10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_E5qzbfDJ, 0, m, &cDelay_E5qzbfDJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HV81fptC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_OtuM2jdA, 2, m, &cDelay_OtuM2jdA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dMBMGj12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_5iV3dFqL, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_G3m1a7cE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tTcFCjLp, HV_BINOP_SUBTRACT, 0, m, &cBinop_tTcFCjLp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Pa1TmUYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_A9ojJNXO_sendMessage);
}

void Heavy_ChaffVerb::cSystem_A9ojJNXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_hg0MsJh4_sendMessage);
}

void Heavy_ChaffVerb::cVar_jd78CtIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J95MXmX0_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_eysDd6SZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eysDd6SZ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_emRYwdNA, 0, m, &cDelay_emRYwdNA_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_xWpkrcHI, 0, m, &sTabread_xWpkrcHI_sendMessage);
}

void Heavy_ChaffVerb::cDelay_emRYwdNA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_emRYwdNA, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_xWpkrcHI, 0, m, &sTabread_xWpkrcHI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_emRYwdNA, 0, m, &cDelay_emRYwdNA_sendMessage);
}

void Heavy_ChaffVerb::sTabread_xWpkrcHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_5aDP6YJu, HV_BINOP_SUBTRACT, 0, m, &cBinop_5aDP6YJu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_Y6Rq2u1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aynaolHI, HV_BINOP_MAX, 0, m, &cBinop_aynaolHI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hg0MsJh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y6Rq2u1V, HV_BINOP_MULTIPLY, 0, m, &cBinop_Y6Rq2u1V_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tTcFCjLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5YBGaWW2_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_xWpkrcHI, 0, m, &sTabread_xWpkrcHI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QXryoE1R_sendMessage);
}

void Heavy_ChaffVerb::cSystem_tkYzaq2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5aDP6YJu, HV_BINOP_SUBTRACT, 1, m, &cBinop_5aDP6YJu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_emRYwdNA, 2, m, &cDelay_emRYwdNA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_J95MXmX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tkYzaq2u_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5YBGaWW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_eysDd6SZ, 0, m, &cDelay_eysDd6SZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_emRYwdNA, 0, m, &cDelay_emRYwdNA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5LDXlkmH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_aynaolHI, HV_BINOP_MAX, 1, m, &cBinop_aynaolHI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_aynaolHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tTcFCjLp, HV_BINOP_SUBTRACT, 1, m, &cBinop_tTcFCjLp_sendMessage);
}

void Heavy_ChaffVerb::cCast_QXryoE1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eysDd6SZ, 0, m, &cDelay_eysDd6SZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_X8q1ANxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eysDd6SZ, 2, m, &cDelay_eysDd6SZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5aDP6YJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_X8q1ANxL_sendMessage);
}

void Heavy_ChaffVerb::cCast_WcRyi5yl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jd78CtIK, 0, m, &cVar_jd78CtIK_sendMessage);
  cMsg_Pa1TmUYL_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_G3m1a7cE, 0, m, &cTabhead_G3m1a7cE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NOUfYYBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8KMcppte_sendMessage);
}

void Heavy_ChaffVerb::cSystem_8KMcppte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_HwGisarQ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_oZ0eWzZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oZ0eWzZv, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vJWzHppQ, 0, m, &cDelay_vJWzHppQ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oZ0eWzZv, 0, m, &cDelay_oZ0eWzZv_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LeOf7Yvh, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_vJWzHppQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vJWzHppQ, m);
  cMsg_LR6HCCau_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_vPLIJ9NN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ZdD368PM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_nr9hcmG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AZ1yOCyG_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_PpWhMVhn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gkdoywtK_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oZ0eWzZv, 2, m, &cDelay_oZ0eWzZv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_taiuHeQf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_AZ1yOCyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_PpWhMVhn, 0, m, &hTable_PpWhMVhn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HwGisarQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 16.364f, 0, m, &cBinop_nr9hcmG9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LR6HCCau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_PpWhMVhn, 0, m, &hTable_PpWhMVhn_sendMessage);
}

void Heavy_ChaffVerb::cCast_taiuHeQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oZ0eWzZv, 0, m, &cDelay_oZ0eWzZv_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gkdoywtK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_vJWzHppQ, 2, m, &cDelay_vJWzHppQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZdD368PM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LeOf7Yvh, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_223ZrU65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5IrKbHW1, HV_BINOP_SUBTRACT, 0, m, &cBinop_5IrKbHW1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iEZSmqrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kkfYAExb_sendMessage);
}

void Heavy_ChaffVerb::cSystem_kkfYAExb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_awcg9lCf_sendMessage);
}

void Heavy_ChaffVerb::cVar_2HlKg5s2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n1JJPvYo_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_nEXUWebE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nEXUWebE, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LIiALJuS, 0, m, &cDelay_LIiALJuS_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_o9xlsr3h, 0, m, &sTabread_o9xlsr3h_sendMessage);
}

void Heavy_ChaffVerb::cDelay_LIiALJuS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LIiALJuS, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_o9xlsr3h, 0, m, &sTabread_o9xlsr3h_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LIiALJuS, 0, m, &cDelay_LIiALJuS_sendMessage);
}

void Heavy_ChaffVerb::sTabread_o9xlsr3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_L3qyQmz1, HV_BINOP_SUBTRACT, 0, m, &cBinop_L3qyQmz1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_TjDKnMA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ji3da3ZD, HV_BINOP_MAX, 0, m, &cBinop_Ji3da3ZD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_awcg9lCf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TjDKnMA9, HV_BINOP_MULTIPLY, 0, m, &cBinop_TjDKnMA9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5IrKbHW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uzUZwZ7i_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_o9xlsr3h, 0, m, &sTabread_o9xlsr3h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QdKhH2uS_sendMessage);
}

void Heavy_ChaffVerb::cSystem_OqlyPdpp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L3qyQmz1, HV_BINOP_SUBTRACT, 1, m, &cBinop_L3qyQmz1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LIiALJuS, 2, m, &cDelay_LIiALJuS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_n1JJPvYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_OqlyPdpp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uzUZwZ7i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_nEXUWebE, 0, m, &cDelay_nEXUWebE_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LIiALJuS, 0, m, &cDelay_LIiALJuS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DdlEoPcu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ji3da3ZD, HV_BINOP_MAX, 1, m, &cBinop_Ji3da3ZD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Ji3da3ZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5IrKbHW1, HV_BINOP_SUBTRACT, 1, m, &cBinop_5IrKbHW1_sendMessage);
}

void Heavy_ChaffVerb::cCast_QdKhH2uS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nEXUWebE, 0, m, &cDelay_nEXUWebE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Eyt53xdJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nEXUWebE, 2, m, &cDelay_nEXUWebE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_L3qyQmz1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Eyt53xdJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_CXVbAjd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2HlKg5s2, 0, m, &cVar_2HlKg5s2_sendMessage);
  cMsg_iEZSmqrJ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_223ZrU65, 0, m, &cTabhead_223ZrU65_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lLqmEPaB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MFqJMr1N_sendMessage);
}

void Heavy_ChaffVerb::cSystem_MFqJMr1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_28PNvjLN_sendMessage);
}

void Heavy_ChaffVerb::cDelay_gwogWSC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gwogWSC8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DFId1suu, 0, m, &cDelay_DFId1suu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gwogWSC8, 0, m, &cDelay_gwogWSC8_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Hc6xyqzq, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_DFId1suu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DFId1suu, m);
  cMsg_xp5J7Q4i_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_XomOoucD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_KNeN6Edt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_TDlTrzVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ka3Xw83a_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_8TEf7XSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jrd8bXqL_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gwogWSC8, 2, m, &cDelay_gwogWSC8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qYMjNW9S_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ka3Xw83a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_8TEf7XSC, 0, m, &hTable_8TEf7XSC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_28PNvjLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 4.2546f, 0, m, &cBinop_TDlTrzVn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xp5J7Q4i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_8TEf7XSC, 0, m, &hTable_8TEf7XSC_sendMessage);
}

void Heavy_ChaffVerb::cCast_qYMjNW9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gwogWSC8, 0, m, &cDelay_gwogWSC8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Jrd8bXqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_DFId1suu, 2, m, &cDelay_DFId1suu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KNeN6Edt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Hc6xyqzq, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_FVQBiQSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VNmdPpjk, HV_BINOP_SUBTRACT, 0, m, &cBinop_VNmdPpjk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JXlmO157_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wRyK2FoD_sendMessage);
}

void Heavy_ChaffVerb::cSystem_wRyK2FoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_EkFuP2Qx_sendMessage);
}

void Heavy_ChaffVerb::cVar_ta0qCkjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2XLnqe3h_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_AUe6XDIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AUe6XDIy, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6gfGygnV, 0, m, &cDelay_6gfGygnV_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_TTyDYDuZ, 0, m, &sTabread_TTyDYDuZ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_6gfGygnV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6gfGygnV, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_TTyDYDuZ, 0, m, &sTabread_TTyDYDuZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6gfGygnV, 0, m, &cDelay_6gfGygnV_sendMessage);
}

void Heavy_ChaffVerb::sTabread_TTyDYDuZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_qlYX83Ic, HV_BINOP_SUBTRACT, 0, m, &cBinop_qlYX83Ic_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_1NhagQTO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sIMzRrzx, HV_BINOP_MAX, 0, m, &cBinop_sIMzRrzx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_EkFuP2Qx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1NhagQTO, HV_BINOP_MULTIPLY, 0, m, &cBinop_1NhagQTO_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VNmdPpjk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gqLUDqvv_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_TTyDYDuZ, 0, m, &sTabread_TTyDYDuZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gB0oAR7c_sendMessage);
}

void Heavy_ChaffVerb::cSystem_wpyCfU8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qlYX83Ic, HV_BINOP_SUBTRACT, 1, m, &cBinop_qlYX83Ic_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6gfGygnV, 2, m, &cDelay_6gfGygnV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2XLnqe3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wpyCfU8l_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gqLUDqvv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AUe6XDIy, 0, m, &cDelay_AUe6XDIy_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6gfGygnV, 0, m, &cDelay_6gfGygnV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ulZXo95N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_sIMzRrzx, HV_BINOP_MAX, 1, m, &cBinop_sIMzRrzx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sIMzRrzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VNmdPpjk, HV_BINOP_SUBTRACT, 1, m, &cBinop_VNmdPpjk_sendMessage);
}

void Heavy_ChaffVerb::cCast_gB0oAR7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AUe6XDIy, 0, m, &cDelay_AUe6XDIy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sUQb65RI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AUe6XDIy, 2, m, &cDelay_AUe6XDIy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qlYX83Ic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_sUQb65RI_sendMessage);
}

void Heavy_ChaffVerb::cCast_a5IEqaep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ta0qCkjA, 0, m, &cVar_ta0qCkjA_sendMessage);
  cMsg_JXlmO157_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_FVQBiQSs, 0, m, &cTabhead_FVQBiQSs_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gdNjJg7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Y77G1TYy_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Y77G1TYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_8SdQUNnl_sendMessage);
}

void Heavy_ChaffVerb::cDelay_1yWFXi0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1yWFXi0s, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UwI3G47h, 0, m, &cDelay_UwI3G47h_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1yWFXi0s, 0, m, &cDelay_1yWFXi0s_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_AwOG3Qk1, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_UwI3G47h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UwI3G47h, m);
  cMsg_Upq6wetg_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_AXelklwA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_PIxPScKj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_BwcV4BR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JeAGeY5V_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_CyQz2ryL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EefvhgRi_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1yWFXi0s, 2, m, &cDelay_1yWFXi0s_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bPcbdU6L_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JeAGeY5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_CyQz2ryL, 0, m, &hTable_CyQz2ryL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8SdQUNnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 7.645f, 0, m, &cBinop_BwcV4BR8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Upq6wetg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_CyQz2ryL, 0, m, &hTable_CyQz2ryL_sendMessage);
}

void Heavy_ChaffVerb::cCast_bPcbdU6L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1yWFXi0s, 0, m, &cDelay_1yWFXi0s_sendMessage);
}

void Heavy_ChaffVerb::cMsg_EefvhgRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_UwI3G47h, 2, m, &cDelay_UwI3G47h_sendMessage);
}

void Heavy_ChaffVerb::cMsg_PIxPScKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_AwOG3Qk1, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_UIW1LznG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m4jp1url, HV_BINOP_SUBTRACT, 0, m, &cBinop_m4jp1url_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9s5nvQAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zOCHQAYt_sendMessage);
}

void Heavy_ChaffVerb::cSystem_zOCHQAYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9WEHQ4Y2_sendMessage);
}

void Heavy_ChaffVerb::cVar_p3nn0JdC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_584Evofi_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_shb9SE1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_shb9SE1I, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fkt9imvW, 0, m, &cDelay_fkt9imvW_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_MqWH9iOI, 0, m, &sTabread_MqWH9iOI_sendMessage);
}

void Heavy_ChaffVerb::cDelay_fkt9imvW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fkt9imvW, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_MqWH9iOI, 0, m, &sTabread_MqWH9iOI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fkt9imvW, 0, m, &cDelay_fkt9imvW_sendMessage);
}

void Heavy_ChaffVerb::sTabread_MqWH9iOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_rYILDlbK, HV_BINOP_SUBTRACT, 0, m, &cBinop_rYILDlbK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_ce7s3GQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kkxJC04R, HV_BINOP_MAX, 0, m, &cBinop_kkxJC04R_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9WEHQ4Y2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ce7s3GQr, HV_BINOP_MULTIPLY, 0, m, &cBinop_ce7s3GQr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_m4jp1url_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_byLaokHY_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_MqWH9iOI, 0, m, &sTabread_MqWH9iOI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L1rfjftq_sendMessage);
}

void Heavy_ChaffVerb::cSystem_USEv7WyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rYILDlbK, HV_BINOP_SUBTRACT, 1, m, &cBinop_rYILDlbK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fkt9imvW, 2, m, &cDelay_fkt9imvW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_584Evofi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_USEv7WyM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_byLaokHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_shb9SE1I, 0, m, &cDelay_shb9SE1I_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fkt9imvW, 0, m, &cDelay_fkt9imvW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_WkZzTjVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_kkxJC04R, HV_BINOP_MAX, 1, m, &cBinop_kkxJC04R_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kkxJC04R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m4jp1url, HV_BINOP_SUBTRACT, 1, m, &cBinop_m4jp1url_sendMessage);
}

void Heavy_ChaffVerb::cCast_L1rfjftq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_shb9SE1I, 0, m, &cDelay_shb9SE1I_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ryEwlVYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_shb9SE1I, 2, m, &cDelay_shb9SE1I_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rYILDlbK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ryEwlVYy_sendMessage);
}

void Heavy_ChaffVerb::cCast_RIhgAcYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_p3nn0JdC, 0, m, &cVar_p3nn0JdC_sendMessage);
  cMsg_9s5nvQAv_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_UIW1LznG, 0, m, &cTabhead_UIW1LznG_sendMessage);
}

void Heavy_ChaffVerb::cVar_1UWACGH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wtIbebV2, 0, m, &cVar_wtIbebV2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lBZRWxTv, 0, m, &cVar_lBZRWxTv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7EE0Wex0, 0, m, &cVar_7EE0Wex0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UtcA5vY3, 0, m, &cVar_UtcA5vY3_sendMessage);
}

void Heavy_ChaffVerb::cVar_Z3Aktc3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.01f, 0, m, &cBinop_gbx76kVC_sendMessage);
}

void Heavy_ChaffVerb::cPack_aD3N9Uhi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_eJ5jMpbR, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_lBZRWxTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YBXa1Rti, HV_BINOP_MULTIPLY, 0, m, &cBinop_YBXa1Rti_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QFYs2eat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_G6l7tDvX_sendMessage);
}

void Heavy_ChaffVerb::cSystem_G6l7tDvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3Ma8mona_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_YBXa1Rti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_541vmR42_sendMessage);
}

void Heavy_ChaffVerb::cBinop_z8OOPXp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YBXa1Rti, HV_BINOP_MULTIPLY, 1, m, &cBinop_YBXa1Rti_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3Ma8mona_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_z8OOPXp0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_541vmR42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_UzZdxetZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UzZdxetZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Zh9XuY3S_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Znay01cp, m);
}

void Heavy_ChaffVerb::cBinop_Zh9XuY3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ZtaDrvMv, m);
}

void Heavy_ChaffVerb::cVar_7EE0Wex0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MNQvS8v1, HV_BINOP_MULTIPLY, 0, m, &cBinop_MNQvS8v1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RNbhx1WN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hZUiNhVc_sendMessage);
}

void Heavy_ChaffVerb::cSystem_hZUiNhVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wTwfyTdK_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_MNQvS8v1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_RPmSMtO1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_E4eubT5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MNQvS8v1, HV_BINOP_MULTIPLY, 1, m, &cBinop_MNQvS8v1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wTwfyTdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_E4eubT5k_sendMessage);
}

void Heavy_ChaffVerb::cBinop_RPmSMtO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_DwbME5fc_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DwbME5fc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Qyz183bH_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_vccBUjBq, m);
}

void Heavy_ChaffVerb::cBinop_Qyz183bH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_iUcGroED, m);
}

void Heavy_ChaffVerb::cVar_UtcA5vY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fGQ89Pfb, HV_BINOP_MULTIPLY, 0, m, &cBinop_fGQ89Pfb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_utWXQMPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BMspjrpR_sendMessage);
}

void Heavy_ChaffVerb::cSystem_BMspjrpR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rV6I1nPJ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_fGQ89Pfb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_lc2WFj1T_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wOTss16k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fGQ89Pfb, HV_BINOP_MULTIPLY, 1, m, &cBinop_fGQ89Pfb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rV6I1nPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wOTss16k_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lc2WFj1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_BGzQ8OLb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BGzQ8OLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Ps0sTM2q_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_QSdT0VTN, m);
}

void Heavy_ChaffVerb::cBinop_Ps0sTM2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6Tm0cU7G, m);
}

void Heavy_ChaffVerb::cBinop_oP6RWEWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_D5RCZpEr, 0, m, &cPack_D5RCZpEr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_D0umbA5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3000.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_1UWACGH9, 0, m, &cVar_1UWACGH9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gbx76kVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_aD3N9Uhi, 0, m, &cPack_aD3N9Uhi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5GUuDzAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_qYRkAo8i, 0, m, &cPack_qYRkAo8i_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_oNLthuZJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_xkGj34Hf_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_xkGj34Hf_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AibGQCnw_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_tGiDF9kU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tGiDF9kU, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tGiDF9kU, 0, m, &cDelay_tGiDF9kU_sendMessage);
  cSwitchcase_RN8hSmWc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_AibGQCnw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xkGj34Hf_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tGiDF9kU, 0, m, &cDelay_tGiDF9kU_sendMessage);
  cSwitchcase_RN8hSmWc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cMsg_jQmFHAqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DjQu1cCX_sendMessage);
}

void Heavy_ChaffVerb::cSystem_DjQu1cCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_MgxUUoLr_sendMessage);
}

void Heavy_ChaffVerb::cVar_1EA5XEP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BlXcb0Yv, HV_BINOP_MULTIPLY, 0, m, &cBinop_BlXcb0Yv_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xkGj34Hf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tGiDF9kU, 0, m, &cDelay_tGiDF9kU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WM8EAZ8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tGiDF9kU, 2, m, &cDelay_tGiDF9kU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MgxUUoLr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BlXcb0Yv, HV_BINOP_MULTIPLY, 1, m, &cBinop_BlXcb0Yv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BlXcb0Yv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_WM8EAZ8d_sendMessage);
}

void Heavy_ChaffVerb::cVar_KI2Xa37x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MOD_UNIPOLAR, 628.0f, 0, m, &cBinop_bM2BSzjY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 2.0f, 0, m, &cBinop_NV8X4x17_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ilRbDb7h_sendMessage);
}

void Heavy_ChaffVerb::cVar_59Ervc34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GNjmzSpI_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_uh0nZfhs, 0, m, &cIf_uh0nZfhs_sendMessage);
}

void Heavy_ChaffVerb::cUnop_lT6xyCgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UIdQyEPU, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_UIdQyEPU_sendMessage);
}

void Heavy_ChaffVerb::cUnop_JdKdfhAY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UIdQyEPU, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_UIdQyEPU_sendMessage);
}

void Heavy_ChaffVerb::cIf_uh0nZfhs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_JdKdfhAY_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_lT6xyCgI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_GNjmzSpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uh0nZfhs, 1, m, &cIf_uh0nZfhs_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fLzBzLs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Xr4zCWUD_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Xr4zCWUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_VlxioCHd_sendMessage);
}

void Heavy_ChaffVerb::cDelay_QFiH8UA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QFiH8UA1, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oWWlS9GR, 0, m, &cDelay_oWWlS9GR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QFiH8UA1, 0, m, &cDelay_QFiH8UA1_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_HWfMrUFA, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_oWWlS9GR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oWWlS9GR, m);
  cMsg_X9bCoI2o_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_lxDdZyGE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_h1EktLEH_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_TZCUZqND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RaM6y1Rj_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_Pb8JBdIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L9K2j7m3_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QFiH8UA1, 2, m, &cDelay_QFiH8UA1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IOriLOSR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RaM6y1Rj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Pb8JBdIn, 0, m, &hTable_Pb8JBdIn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VlxioCHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 3000.0f, 0, m, &cBinop_TZCUZqND_sendMessage);
}

void Heavy_ChaffVerb::cMsg_X9bCoI2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Pb8JBdIn, 0, m, &hTable_Pb8JBdIn_sendMessage);
}

void Heavy_ChaffVerb::cCast_IOriLOSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QFiH8UA1, 0, m, &cDelay_QFiH8UA1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_L9K2j7m3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_oWWlS9GR, 2, m, &cDelay_oWWlS9GR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_h1EktLEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_HWfMrUFA, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_stZ6Ksrm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EmwJ9Ilb, HV_BINOP_SUBTRACT, 0, m, &cBinop_EmwJ9Ilb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0E4nZMrA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_n2vxtfNh_sendMessage);
}

void Heavy_ChaffVerb::cSystem_n2vxtfNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_fvySqpdU_sendMessage);
}

void Heavy_ChaffVerb::cVar_PlRh3U8t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FNtTbUgu_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_mQ8D3avh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mQ8D3avh, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PzdMH4p2, 0, m, &cDelay_PzdMH4p2_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_JpZ3w5Mb, 0, m, &sTabread_JpZ3w5Mb_sendMessage);
}

void Heavy_ChaffVerb::cDelay_PzdMH4p2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PzdMH4p2, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_JpZ3w5Mb, 0, m, &sTabread_JpZ3w5Mb_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PzdMH4p2, 0, m, &cDelay_PzdMH4p2_sendMessage);
}

void Heavy_ChaffVerb::sTabread_JpZ3w5Mb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_s6xFKEkw, HV_BINOP_SUBTRACT, 0, m, &cBinop_s6xFKEkw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_xFs4Xsgy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gdEeuN05, HV_BINOP_MAX, 0, m, &cBinop_gdEeuN05_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fvySqpdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xFs4Xsgy, HV_BINOP_MULTIPLY, 0, m, &cBinop_xFs4Xsgy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_EmwJ9Ilb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WqEAdn7Z_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_JpZ3w5Mb, 0, m, &sTabread_JpZ3w5Mb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nQ1SWBno_sendMessage);
}

void Heavy_ChaffVerb::cSystem_0kcuqAlm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s6xFKEkw, HV_BINOP_SUBTRACT, 1, m, &cBinop_s6xFKEkw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PzdMH4p2, 2, m, &cDelay_PzdMH4p2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FNtTbUgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0kcuqAlm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_WqEAdn7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mQ8D3avh, 0, m, &cDelay_mQ8D3avh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PzdMH4p2, 0, m, &cDelay_PzdMH4p2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jLcxfUQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_gdEeuN05, HV_BINOP_MAX, 1, m, &cBinop_gdEeuN05_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gdEeuN05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EmwJ9Ilb, HV_BINOP_SUBTRACT, 1, m, &cBinop_EmwJ9Ilb_sendMessage);
}

void Heavy_ChaffVerb::cCast_nQ1SWBno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mQ8D3avh, 0, m, &cDelay_mQ8D3avh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QtUinRzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mQ8D3avh, 2, m, &cDelay_mQ8D3avh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_s6xFKEkw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_QtUinRzs_sendMessage);
}

void Heavy_ChaffVerb::cCast_EY5pgjnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PlRh3U8t, 0, m, &cVar_PlRh3U8t_sendMessage);
  cMsg_0E4nZMrA_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_stZ6Ksrm, 0, m, &cTabhead_stZ6Ksrm_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_4wb1bcMm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2KkD4eBx_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_2KkD4eBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vdxNNsXe_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_LipFYMTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cJ0QiSri, HV_BINOP_ADD, 0, m, &cBinop_cJ0QiSri_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_Ax088eZb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iZUPSvmA_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_iZUPSvmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bggxhu6R_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_rBeE5Hr9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LsWNJBJc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nwhuSFFN_sendMessage);
}

void Heavy_ChaffVerb::cVar_sfzs14Gn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xqn2TdMI, 0, m, &cVar_xqn2TdMI_sendMessage);
}

void Heavy_ChaffVerb::cVar_xqn2TdMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Kd9C7dh, HV_BINOP_ADD, 0, m, &cBinop_1Kd9C7dh_sendMessage);
}

void Heavy_ChaffVerb::cVar_886kD50T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M6z7g5xz, HV_BINOP_ADD, 0, m, &cBinop_M6z7g5xz_sendMessage);
}

void Heavy_ChaffVerb::cVar_m2aktvwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nTv34s5b_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_23yQI59R, 0, m, &cIf_23yQI59R_sendMessage);
}

void Heavy_ChaffVerb::cUnop_sYHC5dKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M6z7g5xz, HV_BINOP_ADD, 1, m, &cBinop_M6z7g5xz_sendMessage);
}

void Heavy_ChaffVerb::cUnop_xkJQUEqA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M6z7g5xz, HV_BINOP_ADD, 1, m, &cBinop_M6z7g5xz_sendMessage);
}

void Heavy_ChaffVerb::cIf_23yQI59R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_xkJQUEqA_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_sYHC5dKg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_nTv34s5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_23yQI59R, 1, m, &cIf_23yQI59R_sendMessage);
}

void Heavy_ChaffVerb::cVar_gBK2ClT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_p9s47JFu_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_iQ4OMYl6, 0, m, &cIf_iQ4OMYl6_sendMessage);
}

void Heavy_ChaffVerb::cUnop_Prn6JYsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_H8bTnhF6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_FqPpvLNo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_H8bTnhF6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cIf_iQ4OMYl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_FqPpvLNo_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_Prn6JYsR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_p9s47JFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iQ4OMYl6, 1, m, &cIf_iQ4OMYl6_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_H8bTnhF6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mSMNvRM4, 0, m, &cSlice_mSMNvRM4_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qubknck7, 0, m, &cSlice_qubknck7_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ta4NokNb_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ljxK8xRK_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cSlice_mSMNvRM4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_sVcCB2rT, 0, m, &cVar_sVcCB2rT_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_sVcCB2rT, 0, m, &cVar_sVcCB2rT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSlice_qubknck7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_yMskSg4v, HV_BINOP_NEQ, 1, m, &cBinop_yMskSg4v_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_sVcCB2rT, 1, m, &cVar_sVcCB2rT_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_yMskSg4v, HV_BINOP_NEQ, 1, m, &cBinop_yMskSg4v_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_sVcCB2rT, 1, m, &cVar_sVcCB2rT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cVar_sVcCB2rT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kvLrvGYS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DUV1cUEN_sendMessage);
}

void Heavy_ChaffVerb::cIf_zkzDUhBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ShIBZiWJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6PsfRC9h_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_6PsfRC9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sVcCB2rT, 0, m, &cVar_sVcCB2rT_sendMessage);
}

void Heavy_ChaffVerb::cCast_ShIBZiWJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yMskSg4v, HV_BINOP_NEQ, 1, m, &cBinop_yMskSg4v_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yMskSg4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zkzDUhBy, 1, m, &cIf_zkzDUhBy_sendMessage);
}

void Heavy_ChaffVerb::cCast_ljxK8xRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zkzDUhBy, 0, m, &cIf_zkzDUhBy_sendMessage);
}

void Heavy_ChaffVerb::cCast_Ta4NokNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yMskSg4v, HV_BINOP_NEQ, 0, m, &cBinop_yMskSg4v_sendMessage);
}

void Heavy_ChaffVerb::cIf_nMFx0i3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_sfzs14Gn, 0, m, &cVar_sfzs14Gn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_Ea6VEyy4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_nMFx0i3X, 0, m, &cIf_nMFx0i3X_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_VOjCbw16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_nMFx0i3X, 0, m, &cIf_nMFx0i3X_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_4CqKjsBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_nMFx0i3X, 0, m, &cIf_nMFx0i3X_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_PlbJmkj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_rBeE5Hr9, 0, m, &cVar_rBeE5Hr9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_W0PFAF5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_886kD50T, 0, m, &cVar_886kD50T_sendMessage);
}

void Heavy_ChaffVerb::cMsg_K1c2mgbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Ea6VEyy4, 1, m, &cIf_Ea6VEyy4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_r7vU22kH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_4CqKjsBB, 1, m, &cIf_4CqKjsBB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4SArSTUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Ea6VEyy4, 1, m, &cIf_Ea6VEyy4_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_VOjCbw16, 1, m, &cIf_VOjCbw16_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_4CqKjsBB, 1, m, &cIf_4CqKjsBB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jHaVPOqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LipFYMTZ, 0, m, &cVar_LipFYMTZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rn43klyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_jHaVPOqC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_bggxhu6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_rBeE5Hr9, 0, m, &cVar_rBeE5Hr9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UIdQyEPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_myWN2OBD, HV_BINOP_MULTIPLY, 0, m, &cBinop_myWN2OBD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ilRbDb7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UIdQyEPU, HV_BINOP_MOD_UNIPOLAR, 0, m, &cBinop_UIdQyEPU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xRrZUycG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_VOjCbw16, 1, m, &cIf_VOjCbw16_sendMessage);
}

void Heavy_ChaffVerb::cBinop_M6z7g5xz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ozF0lQlr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2jGub9t4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kmvuOvQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_j5nvqSJP, 0, m, &cVar_j5nvqSJP_sendMessage);
}

void Heavy_ChaffVerb::cCast_2jGub9t4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sfzs14Gn, 0, m, &cVar_sfzs14Gn_sendMessage);
}

void Heavy_ChaffVerb::cCast_ozF0lQlr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kmvuOvQY, HV_BINOP_ADD, 1, m, &cBinop_kmvuOvQY_sendMessage);
}

void Heavy_ChaffVerb::cCast_DUV1cUEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LjEx9g3G_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_kvLrvGYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4SArSTUE_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_EAw8QYCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ha5AksLM, 0, m, &cVar_ha5AksLM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_myWN2OBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VOjCbw16, 0, m, &cIf_VOjCbw16_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Y4UMDK2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4CqKjsBB, 0, m, &cIf_4CqKjsBB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VxxJ5ROH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_a6zmeojr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 3.1415f, 0, m, &cBinop_Y4UMDK2U_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bM2BSzjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 314.0f, 0, m, &cBinop_2eCMCrgq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2eCMCrgq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_VxxJ5ROH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NV8X4x17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KI2Xa37x, 1, m, &cVar_KI2Xa37x_sendMessage);
}

void Heavy_ChaffVerb::cBinop_R4t0oTAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_L2Ua2viC, 0, m, &cVar_L2Ua2viC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ccqZboCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1EA5XEP5, 0, m, &cVar_1EA5XEP5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vdxNNsXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_sfzs14Gn, 0, m, &cVar_sfzs14Gn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cJ0QiSri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u1CLaGaa, HV_BINOP_MULTIPLY, 0, m, &cBinop_u1CLaGaa_sendMessage);
}

void Heavy_ChaffVerb::cBinop_u1CLaGaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PlbJmkj4, 0, m, &cIf_PlbJmkj4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_szFvVZHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kmvuOvQY, HV_BINOP_ADD, 0, m, &cBinop_kmvuOvQY_sendMessage);
}

void Heavy_ChaffVerb::cCast_LsWNJBJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_szFvVZHb, HV_BINOP_ADD, 1, m, &cBinop_szFvVZHb_sendMessage);
}

void Heavy_ChaffVerb::cCast_nwhuSFFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sfzs14Gn, 0, m, &cVar_sfzs14Gn_sendMessage);
}

void Heavy_ChaffVerb::cCast_w87d2Tvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4wb1bcMm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_a0odJvlJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nMFx0i3X, 1, m, &cIf_nMFx0i3X_sendMessage);
}

void Heavy_ChaffVerb::cCast_c5F46YwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LipFYMTZ, 0, m, &cVar_LipFYMTZ_sendMessage);
}

void Heavy_ChaffVerb::cCast_7Uen9V7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u1CLaGaa, HV_BINOP_MULTIPLY, 1, m, &cBinop_u1CLaGaa_sendMessage);
}

void Heavy_ChaffVerb::cCast_t2ZwZVK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Ax088eZb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_vGK1GzaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PlbJmkj4, 1, m, &cIf_PlbJmkj4_sendMessage);
}

void Heavy_ChaffVerb::cCast_PxeuxMNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cJ0QiSri, HV_BINOP_ADD, 1, m, &cBinop_cJ0QiSri_sendMessage);
}

void Heavy_ChaffVerb::cCast_pY9SEvGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LipFYMTZ, 0, m, &cVar_LipFYMTZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HO2QCa8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_szFvVZHb, HV_BINOP_ADD, 0, m, &cBinop_szFvVZHb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1Kd9C7dh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HO2QCa8a, HV_BINOP_MULTIPLY, 0, m, &cBinop_HO2QCa8a_sendMessage);
}

void Heavy_ChaffVerb::cCast_7L27QsNf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sfzs14Gn, 0, m, &cVar_sfzs14Gn_sendMessage);
}

void Heavy_ChaffVerb::cCast_kALoFRl3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HO2QCa8a, HV_BINOP_MULTIPLY, 1, m, &cBinop_HO2QCa8a_sendMessage);
}

void Heavy_ChaffVerb::cCast_8fY3naMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sfzs14Gn, 0, m, &cVar_sfzs14Gn_sendMessage);
}

void Heavy_ChaffVerb::cCast_m8tbQ9uh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Kd9C7dh, HV_BINOP_ADD, 1, m, &cBinop_1Kd9C7dh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QH94rVfN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kvLrvGYS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DUV1cUEN_sendMessage);
}

void Heavy_ChaffVerb::cReceive_9BwMXKXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iNBB7xBp_sendMessage(_c, 0, m);
  cMsg_JYqGiHaX_sendMessage(_c, 0, m);
  cMsg_hAdeH2CU_sendMessage(_c, 0, m);
  cMsg_NOUfYYBC_sendMessage(_c, 0, m);
  cMsg_lLqmEPaB_sendMessage(_c, 0, m);
  cMsg_gdNjJg7H_sendMessage(_c, 0, m);
  cMsg_82nEWbyQ_sendMessage(_c, 0, m);
  cMsg_I5ki9PAK_sendMessage(_c, 0, m);
  cMsg_bWPVsmmP_sendMessage(_c, 0, m);
  cMsg_3rtlKPzO_sendMessage(_c, 0, m);
  cMsg_QmJa2Shl_sendMessage(_c, 0, m);
  cMsg_zybmaf4i_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_wtIbebV2, 0, m, &cVar_wtIbebV2_sendMessage);
  cMsg_QFYs2eat_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lBZRWxTv, 0, m, &cVar_lBZRWxTv_sendMessage);
  cMsg_RNbhx1WN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_7EE0Wex0, 0, m, &cVar_7EE0Wex0_sendMessage);
  cMsg_utWXQMPH_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_UtcA5vY3, 0, m, &cVar_UtcA5vY3_sendMessage);
  cMsg_lp2NgwuV_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vMxs1m4F, 0, m, &cVar_vMxs1m4F_sendMessage);
  cMsg_DcRVp6kE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_L2Ua2viC, 0, m, &cVar_L2Ua2viC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8ADDGzmp, 0, m, &cVar_8ADDGzmp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ha5AksLM, 0, m, &cVar_ha5AksLM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8Hw8EnAU, 0, m, &cVar_8Hw8EnAU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4J8Wd9NU, 0, m, &cVar_4J8Wd9NU_sendMessage);
  cMsg_jQmFHAqh_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_1EA5XEP5, 0, m, &cVar_1EA5XEP5_sendMessage);
  cMsg_fLzBzLs9_sendMessage(_c, 0, m);
  cSwitchcase_1AynuYoS_onMessage(_c, NULL, 0, m, NULL);
  cMsg_vdxNNsXe_sendMessage(_c, 0, m);
  cMsg_QH94rVfN_sendMessage(_c, 0, m);
  cMsg_bggxhu6R_sendMessage(_c, 0, m);
  cSwitchcase_oNLthuZJ_onMessage(_c, NULL, 0, m, NULL);
  cVar_onMessage(_c, &Context(_c)->cVar_oVunIFaQ, 0, m, &cVar_oVunIFaQ_sendMessage);
  cMsg_qgCXF2IX_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_OJ359UeV, 0, m, &cVar_OJ359UeV_sendMessage);
  cMsg_N60Ixq33_sendMessage(_c, 0, m);
  cMsg_CPPqI6mb_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_4AUPQKZB, 0, m, &cVar_4AUPQKZB_sendMessage);
  cMsg_6I4sTYfX_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_JY6feawi, 0, m, &cTabhead_JY6feawi_sendMessage);
  cMsg_s51VwQUP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_2WMtqrKQ, 0, m, &cVar_2WMtqrKQ_sendMessage);
  cMsg_iDubDUz7_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Zbb23RTW, 0, m, &cTabhead_Zbb23RTW_sendMessage);
  cMsg_rvlX9iTS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Dc0sXUgZ, 0, m, &cVar_Dc0sXUgZ_sendMessage);
  cMsg_mCawOMRv_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_altUcpBY, 0, m, &cTabhead_altUcpBY_sendMessage);
  cMsg_TiR7qfTT_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ZDhXYvXv, 0, m, &cVar_ZDhXYvXv_sendMessage);
  cMsg_efUGlpnc_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_iZYtEKa5, 0, m, &cTabhead_iZYtEKa5_sendMessage);
  cMsg_5jFx4EkI_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_rIKEKlny, 0, m, &cVar_rIKEKlny_sendMessage);
  cMsg_WeG10SZN_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_HXqiHGef, 0, m, &cTabhead_HXqiHGef_sendMessage);
  cMsg_xld6Pxy3_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_4nRoI4PF, 0, m, &cVar_4nRoI4PF_sendMessage);
  cMsg_Oq62Enkl_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_BbrRDu9M, 0, m, &cTabhead_BbrRDu9M_sendMessage);
  cMsg_5LDXlkmH_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_jd78CtIK, 0, m, &cVar_jd78CtIK_sendMessage);
  cMsg_Pa1TmUYL_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_G3m1a7cE, 0, m, &cTabhead_G3m1a7cE_sendMessage);
  cMsg_DdlEoPcu_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_2HlKg5s2, 0, m, &cVar_2HlKg5s2_sendMessage);
  cMsg_iEZSmqrJ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_223ZrU65, 0, m, &cTabhead_223ZrU65_sendMessage);
  cMsg_ulZXo95N_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ta0qCkjA, 0, m, &cVar_ta0qCkjA_sendMessage);
  cMsg_JXlmO157_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_FVQBiQSs, 0, m, &cTabhead_FVQBiQSs_sendMessage);
  cMsg_WkZzTjVo_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_p3nn0JdC, 0, m, &cVar_p3nn0JdC_sendMessage);
  cMsg_9s5nvQAv_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_UIW1LznG, 0, m, &cTabhead_UIW1LznG_sendMessage);
  cMsg_jLcxfUQy_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PlRh3U8t, 0, m, &cVar_PlRh3U8t_sendMessage);
  cMsg_0E4nZMrA_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_stZ6Ksrm, 0, m, &cTabhead_stZ6Ksrm_sendMessage);
}

void Heavy_ChaffVerb::cReceive_sMowLSnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_R4t0oTAP_sendMessage);
}

void Heavy_ChaffVerb::cReceive_P9PebINy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gBK2ClT2, 0, m, &cVar_gBK2ClT2_sendMessage);
}

void Heavy_ChaffVerb::cReceive_NBXnPyJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_59Ervc34, 0, m, &cVar_59Ervc34_sendMessage);
}

void Heavy_ChaffVerb::cReceive_MkQEhkja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_myWN2OBD, HV_BINOP_MULTIPLY, 1, m, &cBinop_myWN2OBD_sendMessage);
}

void Heavy_ChaffVerb::cReceive_2kh2VRtT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m8tbQ9uh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8fY3naMX_sendMessage);
}

void Heavy_ChaffVerb::cReceive_wo4yv7XS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kALoFRl3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7L27QsNf_sendMessage);
}

void Heavy_ChaffVerb::cReceive_HH0uy2ie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_886kD50T, 0, m, &cVar_886kD50T_sendMessage);
}

void Heavy_ChaffVerb::cReceive_aOOkkEgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W0PFAF5l_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_m2aktvwy, 0, m, &cVar_m2aktvwy_sendMessage);
}

void Heavy_ChaffVerb::cReceive_4XuwuZuI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_ccqZboCg_sendMessage);
}

void Heavy_ChaffVerb::cReceive_T3ihUu5s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PxeuxMNe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pY9SEvGH_sendMessage);
}

void Heavy_ChaffVerb::cReceive_vWgsNPsL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7Uen9V7u_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c5F46YwY_sendMessage);
}

void Heavy_ChaffVerb::cReceive_VFDVpqBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vGK1GzaQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t2ZwZVK1_sendMessage);
}

void Heavy_ChaffVerb::cReceive_QCHDi9vB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_JViu2CSr, m);
}

void Heavy_ChaffVerb::cReceive_3jn2O1Nw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_NZwpsiSR, m);
}

void Heavy_ChaffVerb::cReceive_gJzdxH30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8ADDGzmp, 0, m, &cVar_8ADDGzmp_sendMessage);
}

void Heavy_ChaffVerb::cReceive_sW0RXAIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_EAw8QYCE_sendMessage);
}

void Heavy_ChaffVerb::cReceive_s8dKQ0fH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y7Mv0xII, 0, m, &cVar_Y7Mv0xII_sendMessage);
}

void Heavy_ChaffVerb::cReceive_tN7youEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w7x1ePiN, 0, m, &cVar_w7x1ePiN_sendMessage);
}

void Heavy_ChaffVerb::cReceive_REytMAWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vMxs1m4F, 0, m, &cVar_vMxs1m4F_sendMessage);
}

void Heavy_ChaffVerb::cReceive_5NJF82WT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_SEsSoQob, m);
}

void Heavy_ChaffVerb::cReceive_O9gKiWdP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_MRkBSpLf, m);
}

void Heavy_ChaffVerb::cReceive_rBtlhfJk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xFs4Xsgy, HV_BINOP_MULTIPLY, 1, m, &cBinop_xFs4Xsgy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EY5pgjnl_sendMessage);
}

void Heavy_ChaffVerb::cReceive_0Ywf6VDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a0odJvlJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w87d2Tvj_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_ChaffVerb::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_phasor_k_f(&sPhasor_5lSPLxw2, VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf4), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf5), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf1), VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_j38q5Sh6, VOf(Bf4));
    __hv_line_f(&sLine_F0Jkbzms, VOf(Bf1));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf2));
    __hv_tabhead_f(&sTabhead_l9WsAcen, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_mkxZFISX, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_NuTrgtoe, VOf(Bf2));
    __hv_min_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf6));
    __hv_varread_f(&sVarf_HiQO2z3M, VOf(Bf2));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf2), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_V1RoKIgy, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_TrRonSpA, VIi(Bi0), VOf(Bf2));
    __hv_sub_f(VIf(Bf7), VIf(Bf2), VOf(Bf7));
    __hv_sub_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf0));
    __hv_sub_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_floor_f(VIf(Bf7), VOf(Bf6));
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_abs_f(VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf6), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf7), VIf(Bf7), VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf8), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf9), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_tabhead_f(&sTabhead_QTyUkdH9, VOf(Bf4));
    __hv_var_k_f_r(VOf(Bf0), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_IpPouE2U, VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_wxyC3mEu, VOf(Bf1));
    __hv_min_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_max_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf0));
    __hv_varread_f(&sVarf_8Fd4WEAn, VOf(Bf1));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_yVuhhqpz, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_TaxFNQfy, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf8), VIf(Bf1), VOf(Bf8));
    __hv_sub_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf8), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_pZJF94pi, VIf(I0));
    __hv_varread_f(&sVarf_XzQQSXwW, VOf(Bf2));
    __hv_rpole_f(&sRPole_MDM2KImo, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_UtWig8i2, VIf(Bf2), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_zOG8ATgT, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_SEsSoQob, VOf(Bf1));
    __hv_tabread_f(&sTabread_JpZ3w5Mb, VOf(Bf5));
    __hv_varread_f(&sVarf_MRkBSpLf, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_tabwrite_f(&sTabwrite_HWfMrUFA, VIf(Bf9));
    __hv_varread_f(&sVarf_NZwpsiSR, VOf(Bf9));
    __hv_fma_f(VIf(I0), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabread_f(&sTabread_bsqk3m8h, VOf(Bf9));
    __hv_varread_f(&sVarf_pkqbUEM8, VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_vzHyYz4V, VOf(Bf2));
    __hv_rpole_f(&sRPole_hwcpYarA, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf2), VIf(Bf9), VOf(Bf2));
    __hv_line_f(&sLine_eJ5jMpbR, VOf(Bf1));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_ZHE9GDwp, VOf(Bf2));
    __hv_tabread_f(&sTabread_oZbqnJdr, VOf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(Bf0), VOf(Bf8));
    __hv_tabread_f(&sTabread_KZ0v6kZ2, VOf(Bf4));
    __hv_add_f(VIf(Bf8), VIf(Bf4), VOf(Bf6));
    __hv_tabread_f(&sTabread_xWpkrcHI, VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf3));
    __hv_tabread_f(&sTabread_o9xlsr3h, VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf10), VOf(Bf11));
    __hv_tabread_f(&sTabread_MqWH9iOI, VOf(Bf12));
    __hv_add_f(VIf(Bf11), VIf(Bf12), VOf(Bf13));
    __hv_tabread_f(&sTabread_TTyDYDuZ, VOf(Bf14));
    __hv_tabwrite_f(&sTabwrite_9HVhWerm, VIf(Bf5));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_9NMMb84r, VIf(Bf0));
    __hv_sub_f(VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_5iV3dFqL, VIf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_LeOf7Yvh, VIf(Bf7));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_Hc6xyqzq, VIf(Bf12));
    __hv_sub_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_AwOG3Qk1, VIf(Bf10));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_tabread_f(&sTabread_Pf8Caw31, VOf(Bf9));
    __hv_varread_f(&sVarf_Znay01cp, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_ZtaDrvMv, VOf(Bf3));
    __hv_rpole_f(&sRPole_EvinB8mB, VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf3));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf13), VIf(Bf14), VOf(Bf9));
    __hv_tabread_f(&sTabread_gULkidyi, VOf(Bf3));
    __hv_varread_f(&sVarf_vccBUjBq, VOf(Bf10));
    __hv_mul_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_iUcGroED, VOf(Bf12));
    __hv_rpole_f(&sRPole_xKnmE4bU, VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf12));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf3));
    __hv_tabread_f(&sTabread_7tIINPOS, VOf(Bf12));
    __hv_varread_f(&sVarf_QSdT0VTN, VOf(Bf10));
    __hv_mul_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_6Tm0cU7G, VOf(Bf11));
    __hv_rpole_f(&sRPole_7hdmz0eI, VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf3), VIf(Bf2), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_PgPn9nrj, VIf(Bf1));
    __hv_sub_f(VIf(Bf13), VIf(Bf14), VOf(Bf1));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf11));
    __hv_add_f(VIf(Bf1), VIf(Bf11), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_9GqrFB3i, VIf(Bf10));
    __hv_sub_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_uPKXWkof, VIf(Bf12));
    __hv_sub_f(VIf(Bf1), VIf(Bf11), VOf(Bf11));
    __hv_tabwrite_f(&sTabwrite_JbR6MEOD, VIf(Bf11));
    __hv_line_f(&sLine_pr3NjtZ3, VOf(Bf11));
    __hv_mul_f(VIf(Bf13), VIf(Bf11), VOf(Bf13));
    __hv_mul_f(VIf(Bf14), VIf(Bf11), VOf(Bf14));
    __hv_mul_f(VIf(Bf3), VIf(Bf11), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf14), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_JViu2CSr, VOf(Bf3));
    __hv_mul_f(VIf(I0), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf11), VIf(Bf3), VOf(Bf11));
    __hv_add_f(VIf(Bf11), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf13), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_ChaffVerb::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s)
  float **const bIn = &inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_ChaffVerb::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s), uninterleave
  float *const bIn = inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
